from rdflib import URIRef

# WARNING. This is a Generated File. Please do not edit.
# Please refer to the README at java/src/main/java/com/ncc/aif/ont2javagen for more information
# Last generated on: 08/24/2020 11:09:20
NAMESPACE = 'https://raw.githubusercontent.com/NextCenturyCorporation/AIDA-Interchange-Format/master/java/src/main/resources/com/ncc/aif/ontologies/EventsWithFringe#'

# Classes
ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR = URIRef(NAMESPACE + 'ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR')
ACT_AS_LEGAL_AUTHORITY_AGENT = URIRef(NAMESPACE + 'ACT_AS_LEGAL_AUTHORITY_AGENT')
ADJUDICATE = URIRef(NAMESPACE + 'ADJUDICATE')
ADJUDICATOR = URIRef(NAMESPACE + 'ADJUDICATOR')
AFFILIATED_WITH_OPINION_SIDE_AGENT_TOPIC = URIRef(NAMESPACE + 'AFFILIATED_WITH_OPINION_SIDE_AGENT_TOPIC')
AFTER_TRIAL_HEARING = URIRef(NAMESPACE + 'AFTER_TRIAL_HEARING')
AFTER_TRIAL_HEARING_ = URIRef(NAMESPACE + 'AFTER_TRIAL_HEARING-')
AGENT = URIRef(NAMESPACE + 'AGENT')
AGREE_TO_ADJUDICATOR_TOPIC = URIRef(NAMESPACE + 'AGREE_TO_ADJUDICATOR_TOPIC')
AGREE_TO_ADJUDICATOR_TOPIC_ = URIRef(NAMESPACE + 'AGREE_TO_ADJUDICATOR_TOPIC-')
AGREE_TO_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'AGREE_TO_RECIPIENT_TOPIC')
ALLOW = URIRef(NAMESPACE + 'ALLOW')
ALLOWED_ENTRY_BENEFICIARY = URIRef(NAMESPACE + 'ALLOWED_ENTRY_BENEFICIARY')
ALLOWED_ENTRY_BENEFICIARY_ = URIRef(NAMESPACE + 'ALLOWED_ENTRY_BENEFICIARY-')
ALLOWED_TO_EXIT_LOCATION_PATIENT_PLACE_ = URIRef(NAMESPACE + 'ALLOWED_TO_EXIT_LOCATION_PATIENT_PLACE-')
ALLOWED_TO_PARTICIPATE_IN_CHANGE_OF_POSSESSION_PATIENT_ = URIRef(NAMESPACE + 'ALLOWED_TO_PARTICIPATE_IN_CHANGE_OF_POSSESSION_PATIENT-')
ALLOW_ = URIRef(NAMESPACE + 'ALLOW-')
ALLOW_CHANGE_OF_POSS_PATIENT_ = URIRef(NAMESPACE + 'ALLOW_CHANGE_OF_POSS_PATIENT-')
ALLOW_COMMUNICATION_BENEFICIARY_PATIENT_ = URIRef(NAMESPACE + 'ALLOW_COMMUNICATION_BENEFICIARY_PATIENT-')
ALLOW_EXIT = URIRef(NAMESPACE + 'ALLOW_EXIT')
ASSET = URIRef(NAMESPACE + 'ASSET')
ATTEMPT_HARM_AGENT_AGENT = URIRef(NAMESPACE + 'ATTEMPT_HARM_AGENT_AGENT')
ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'ATTEMPT_HARM_AGENT_PATIENT')
ATTEMPT_HARM_PATIENT_AGENT = URIRef(NAMESPACE + 'ATTEMPT_HARM_PATIENT_AGENT')
AWARE_OF_EVENT_PATIENT = URIRef(NAMESPACE + 'AWARE_OF_EVENT_PATIENT')
AWARE_OF_EVENT_PATIENT_ = URIRef(NAMESPACE + 'AWARE_OF_EVENT_PATIENT-')
Accept_AgreementContractCeasefire = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire')
Accept_AgreementContractCeasefire_ADJUDICATE = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-ADJUDICATE')
Accept_AgreementContractCeasefire_ADJUDICATOR = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-ADJUDICATOR')
Accept_AgreementContractCeasefire_AGREE_TO_ADJUDICATOR_TOPIC = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-AGREE_TO_ADJUDICATOR_TOPIC')
Accept_AgreementContractCeasefire_AGREE_TO_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-AGREE_TO_RECIPIENT_TOPIC')
Accept_AgreementContractCeasefire_CREATED_TOPIC = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-CREATED_TOPIC')
Accept_AgreementContractCeasefire_ENACT_ADJUDICATOR_TOPIC = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-ENACT_ADJUDICATOR_TOPIC')
Accept_AgreementContractCeasefire_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-LEGALLY_IMPOSED')
Accept_AgreementContractCeasefire_MAKE_CONTRACT_ADJUDICATOR_RECIPIENT = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-MAKE_CONTRACT_ADJUDICATOR_RECIPIENT')
Accept_AgreementContractCeasefire_PUBLIC_VOTE_ = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-PUBLIC_VOTE-')
Accept_AgreementContractCeasefire_RECIPIENT = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-RECIPIENT')
Accept_AgreementContractCeasefire_REPRESENT_ORG_GPE_ADJUDICATOR = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-REPRESENT_ORG_GPE_ADJUDICATOR')
Accept_AgreementContractCeasefire_REPRESENT_ORG_GPE_RECIPIENT = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-REPRESENT_ORG_GPE_RECIPIENT')
Accept_AgreementContractCeasefire_TOPIC = URIRef(NAMESPACE + 'Accept_AgreementContractCeasefire-TOPIC')
AccidentCrash = URIRef(NAMESPACE + 'AccidentCrash')
AccidentCrash_CAUSER = URIRef(NAMESPACE + 'AccidentCrash-CAUSER')
AccidentCrash_NATURAL_PROCESS_ = URIRef(NAMESPACE + 'AccidentCrash-NATURAL_PROCESS-')
AccidentCrash_PATIENT = URIRef(NAMESPACE + 'AccidentCrash-PATIENT')
Acquit = URIRef(NAMESPACE + 'Acquit')
Acquit_ADJUDICATOR = URIRef(NAMESPACE + 'Acquit-ADJUDICATOR')
Acquit_BELIEVE_TO_BE_TRUE_ADJUDICATOR_CRIME_OR_CAUSE_ = URIRef(NAMESPACE + 'Acquit-BELIEVE_TO_BE_TRUE_ADJUDICATOR_CRIME_OR_CAUSE-')
Acquit_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Acquit-CRIME_OR_CAUSE')
Acquit_DEFENDANT = URIRef(NAMESPACE + 'Acquit-DEFENDANT')
Acquit_ENTAIL_FUTURE_LEGAL_PUNISHMENT_ = URIRef(NAMESPACE + 'Acquit-ENTAIL_FUTURE_LEGAL_PUNISHMENT-')
Acquit_PROSECUTOR = URIRef(NAMESPACE + 'Acquit-PROSECUTOR')
AcuteNaturalDisaster = URIRef(NAMESPACE + 'AcuteNaturalDisaster')
AcuteNaturalDisaster_CAUSER = URIRef(NAMESPACE + 'AcuteNaturalDisaster-CAUSER')
AcuteNaturalDisaster_LARGE_NUMBERS_PATIENT = URIRef(NAMESPACE + 'AcuteNaturalDisaster-LARGE_NUMBERS_PATIENT')
AcuteNaturalDisaster_NATURAL_PROCESS = URIRef(NAMESPACE + 'AcuteNaturalDisaster-NATURAL_PROCESS')
AcuteNaturalDisaster_PATIENT = URIRef(NAMESPACE + 'AcuteNaturalDisaster-PATIENT')
AirstrikeMissileStrike = URIRef(NAMESPACE + 'AirstrikeMissileStrike')
AirstrikeMissileStrike_AGENT = URIRef(NAMESPACE + 'AirstrikeMissileStrike-AGENT')
AirstrikeMissileStrike_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'AirstrikeMissileStrike-ATTEMPT_HARM_AGENT_PATIENT')
AirstrikeMissileStrike_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'AirstrikeMissileStrike-ENTROPY_INCREASE_PATIENT')
AirstrikeMissileStrike_INSTR = URIRef(NAMESPACE + 'AirstrikeMissileStrike-INSTR')
AirstrikeMissileStrike_PATIENT = URIRef(NAMESPACE + 'AirstrikeMissileStrike-PATIENT')
AirstrikeMissileStrike_PHYSICALACTION = URIRef(NAMESPACE + 'AirstrikeMissileStrike-PHYSICALACTION')
AirstrikeMissileStrike_POLITICAL_ = URIRef(NAMESPACE + 'AirstrikeMissileStrike-POLITICAL-')
AirstrikeMissileStrike_PROJECTILE_MANNER = URIRef(NAMESPACE + 'AirstrikeMissileStrike-PROJECTILE_MANNER')
AirstrikeMissileStrike_USE_AGENT_INSTR = URIRef(NAMESPACE + 'AirstrikeMissileStrike-USE_AGENT_INSTR')
AirstrikeMissileStrike_VIOLENT = URIRef(NAMESPACE + 'AirstrikeMissileStrike-VIOLENT')
Appeal = URIRef(NAMESPACE + 'Appeal')
Appeal_ADJUDICATOR = URIRef(NAMESPACE + 'Appeal-ADJUDICATOR')
Appeal_AFTER_TRIAL_HEARING = URIRef(NAMESPACE + 'Appeal-AFTER_TRIAL_HEARING')
Appeal_BEFORE_TRIAL_HEARING = URIRef(NAMESPACE + 'Appeal-BEFORE_TRIAL_HEARING')
Appeal_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Appeal-CRIME_OR_CAUSE')
Appeal_DEFENDANT = URIRef(NAMESPACE + 'Appeal-DEFENDANT')
Appeal_DURING_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Appeal-DURING_TRIAL_HEARING-')
Appeal_PROSECUTOR = URIRef(NAMESPACE + 'Appeal-PROSECUTOR')
Appeal_SENTENCE = URIRef(NAMESPACE + 'Appeal-SENTENCE')
ArrestJailDetain = URIRef(NAMESPACE + 'ArrestJailDetain')
ArrestJailDetain_AGENT = URIRef(NAMESPACE + 'ArrestJailDetain-AGENT')
ArrestJailDetain_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'ArrestJailDetain-CRIME_OR_CAUSE')
ArrestJailDetain_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'ArrestJailDetain-LEGALLY_IMPOSED')
ArrestJailDetain_PATIENT = URIRef(NAMESPACE + 'ArrestJailDetain-PATIENT')
ArrestJailDetain_PLACE = URIRef(NAMESPACE + 'ArrestJailDetain-PLACE')
ArrestJailDetain_PUNISHMENT_FOR_CRIME = URIRef(NAMESPACE + 'ArrestJailDetain-PUNISHMENT_FOR_CRIME')
Arrive = URIRef(NAMESPACE + 'Arrive')
Arrive_COTHEME = URIRef(NAMESPACE + 'Arrive-COTHEME')
Arrive_END_AT_LOCATION_THEME_DESTINATION = URIRef(NAMESPACE + 'Arrive-END_AT_LOCATION_THEME_DESTINATION')
Arrive_SELF_MOTION_THEME = URIRef(NAMESPACE + 'Arrive-SELF_MOTION_THEME')
Arrive_THEME = URIRef(NAMESPACE + 'Arrive-THEME')
AttemptRebellion = URIRef(NAMESPACE + 'AttemptRebellion')
AttemptRebellion_AGENT = URIRef(NAMESPACE + 'AttemptRebellion-AGENT')
AttemptRebellion_PATIENT = URIRef(NAMESPACE + 'AttemptRebellion-PATIENT')
AttemptRebellion_PHYSICALACTION = URIRef(NAMESPACE + 'AttemptRebellion-PHYSICALACTION')
AttemptRebellion_REJECT_LEADERSHIP = URIRef(NAMESPACE + 'AttemptRebellion-REJECT_LEADERSHIP')
AttemptRebellion_TOPIC = URIRef(NAMESPACE + 'AttemptRebellion-TOPIC')
AttemptRebellion_VIOLENT = URIRef(NAMESPACE + 'AttemptRebellion-VIOLENT')
BEFORE_TRIAL_HEARING = URIRef(NAMESPACE + 'BEFORE_TRIAL_HEARING')
BEFORE_TRIAL_HEARING_ = URIRef(NAMESPACE + 'BEFORE_TRIAL_HEARING-')
BELIEVE_TO_BE_TRUE_ADJUDICATOR_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'BELIEVE_TO_BE_TRUE_ADJUDICATOR_CRIME_OR_CAUSE')
BELIEVE_TO_BE_TRUE_ADJUDICATOR_CRIME_OR_CAUSE_ = URIRef(NAMESPACE + 'BELIEVE_TO_BE_TRUE_ADJUDICATOR_CRIME_OR_CAUSE-')
BELIEVE_TO_BE_TRUE_AGENT_TOPIC = URIRef(NAMESPACE + 'BELIEVE_TO_BE_TRUE_AGENT_TOPIC')
BELIEVE_TO_BE_TRUE_AGENT_TOPIC_ = URIRef(NAMESPACE + 'BELIEVE_TO_BE_TRUE_AGENT_TOPIC-')
BELIEVE_TO_BE_TRUE_Adjudicator_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'BELIEVE_TO_BE_TRUE_Adjudicator_CRIME_OR_CAUSE')
BENEFICIARY = URIRef(NAMESPACE + 'BENEFICIARY')
BE_IN_RACE_FOR_CANDIDATE_POSITION = URIRef(NAMESPACE + 'BE_IN_RACE_FOR_CANDIDATE_POSITION')
BUSINESS = URIRef(NAMESPACE + 'BUSINESS')
BUSINESS_ = URIRef(NAMESPACE + 'BUSINESS-')
BiologicalChemicalPoisonAttack = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack')
BiologicalChemicalPoisonAttack_AGENT = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack-AGENT')
BiologicalChemicalPoisonAttack_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack-ATTEMPT_HARM_AGENT_PATIENT')
BiologicalChemicalPoisonAttack_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack-ENTROPY_INCREASE_PATIENT')
BiologicalChemicalPoisonAttack_INSTR = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack-INSTR')
BiologicalChemicalPoisonAttack_PATIENT = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack-PATIENT')
BiologicalChemicalPoisonAttack_PHYSICALACTION = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack-PHYSICALACTION')
BiologicalChemicalPoisonAttack_POLITICAL_ = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack-POLITICAL-')
BiologicalChemicalPoisonAttack_USE_AGENT_INSTR = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack-USE_AGENT_INSTR')
BiologicalChemicalPoisonAttack_VIOLENT = URIRef(NAMESPACE + 'BiologicalChemicalPoisonAttack-VIOLENT')
BirthCure = URIRef(NAMESPACE + 'BirthCure')
BirthCure_AGENT = URIRef(NAMESPACE + 'BirthCure-AGENT')
BirthCure_CHANGES_STATE_PATIENT = URIRef(NAMESPACE + 'BirthCure-CHANGES_STATE_PATIENT')
BirthCure_CONCRETE_PATIENT = URIRef(NAMESPACE + 'BirthCure-CONCRETE_PATIENT')
BirthCure_DESTROYED_PATIENT_ = URIRef(NAMESPACE + 'BirthCure-DESTROYED_PATIENT-')
BirthCure_ENTROPY_INCREASE_ = URIRef(NAMESPACE + 'BirthCure-ENTROPY_INCREASE-')
BirthCure_PATIENT = URIRef(NAMESPACE + 'BirthCure-PATIENT')
BirthCure_SENTIENT_PATIENT = URIRef(NAMESPACE + 'BirthCure-SENTIENT_PATIENT')
BirthCure_VIOLENT_ = URIRef(NAMESPACE + 'BirthCure-VIOLENT-')
Bombing = URIRef(NAMESPACE + 'Bombing')
Bombing_AGENT = URIRef(NAMESPACE + 'Bombing-AGENT')
Bombing_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'Bombing-ATTEMPT_HARM_AGENT_PATIENT')
Bombing_INSTR = URIRef(NAMESPACE + 'Bombing-INSTR')
Bombing_PATIENT = URIRef(NAMESPACE + 'Bombing-PATIENT')
Bombing_PHYSICALACTION = URIRef(NAMESPACE + 'Bombing-PHYSICALACTION')
Bombing_POLITICAL_ = URIRef(NAMESPACE + 'Bombing-POLITICAL-')
Bombing_USE_AGENT_INSTR = URIRef(NAMESPACE + 'Bombing-USE_AGENT_INSTR')
Bombing_VIOLENT = URIRef(NAMESPACE + 'Bombing-VIOLENT')
BorrowLend = URIRef(NAMESPACE + 'BorrowLend')
BorrowLend_DONOR = URIRef(NAMESPACE + 'BorrowLend-DONOR')
BorrowLend_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'BorrowLend-GAIN_POSSESSION_RECIPIENT_PATIENT')
BorrowLend_IS_CRIME_OR_CRIMINAL_ = URIRef(NAMESPACE + 'BorrowLend-IS_CRIME_OR_CRIMINAL-')
BorrowLend_LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'BorrowLend-LEGALLY_IMPOSED-')
BorrowLend_LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'BorrowLend-LOSE_POSSESSION_DONOR_PATIENT')
BorrowLend_PATIENT = URIRef(NAMESPACE + 'BorrowLend-PATIENT')
BorrowLend_RECIPIENT = URIRef(NAMESPACE + 'BorrowLend-RECIPIENT')
BreakUndo = URIRef(NAMESPACE + 'BreakUndo')
BreakUndo_AGENT = URIRef(NAMESPACE + 'BreakUndo-AGENT')
BreakUndo_CHANGES_STATE_PATIENT = URIRef(NAMESPACE + 'BreakUndo-CHANGES_STATE_PATIENT')
BreakUndo_CONCRETE_PATIENT = URIRef(NAMESPACE + 'BreakUndo-CONCRETE_PATIENT')
BreakUndo_ENTROPY_INCREASE = URIRef(NAMESPACE + 'BreakUndo-ENTROPY_INCREASE')
BreakUndo_INSTR = URIRef(NAMESPACE + 'BreakUndo-INSTR')
BreakUndo_PATIENT = URIRef(NAMESPACE + 'BreakUndo-PATIENT')
BreakUndo_SENTIENT_PATIENT_ = URIRef(NAMESPACE + 'BreakUndo-SENTIENT_PATIENT-')
Bribe = URIRef(NAMESPACE + 'Bribe')
Bribe_DONOR = URIRef(NAMESPACE + 'Bribe-DONOR')
Bribe_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'Bribe-GAIN_POSSESSION_RECIPIENT_PATIENT')
Bribe_IS_CRIME_OR_CRIMINAL = URIRef(NAMESPACE + 'Bribe-IS_CRIME_OR_CRIMINAL')
Bribe_LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'Bribe-LEGALLY_IMPOSED-')
Bribe_LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'Bribe-LOSE_POSSESSION_DONOR_PATIENT')
Bribe_PATIENT = URIRef(NAMESPACE + 'Bribe-PATIENT')
Bribe_PAYS_FOR_PAST_FUTURE_ACTION = URIRef(NAMESPACE + 'Bribe-PAYS_FOR_PAST_FUTURE_ACTION')
Bribe_RECIPIENT = URIRef(NAMESPACE + 'Bribe-RECIPIENT')
BringCarryUnload = URIRef(NAMESPACE + 'BringCarryUnload')
BringCarryUnload_CHANGES_LOCATION_COTHEME = URIRef(NAMESPACE + 'BringCarryUnload-CHANGES_LOCATION_COTHEME')
BringCarryUnload_COLOCATED_THEME_COTHEME = URIRef(NAMESPACE + 'BringCarryUnload-COLOCATED_THEME_COTHEME')
BringCarryUnload_COTHEME = URIRef(NAMESPACE + 'BringCarryUnload-COTHEME')
BringCarryUnload_DESTINATION = URIRef(NAMESPACE + 'BringCarryUnload-DESTINATION')
BringCarryUnload_END_AT_LOCATION_COTHEME_DESTINATION = URIRef(NAMESPACE + 'BringCarryUnload-END_AT_LOCATION_COTHEME_DESTINATION')
BringCarryUnload_END_AT_LOCATION_THEME_DESTINATION = URIRef(NAMESPACE + 'BringCarryUnload-END_AT_LOCATION_THEME_DESTINATION')
BringCarryUnload_INITIAL_LOCATION = URIRef(NAMESPACE + 'BringCarryUnload-INITIAL_LOCATION')
BringCarryUnload_SELF_MOTION_THEME = URIRef(NAMESPACE + 'BringCarryUnload-SELF_MOTION_THEME')
BringCarryUnload_START_AT_LOCATION_COTHEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'BringCarryUnload-START_AT_LOCATION_COTHEME_INITIAL_LOCATION')
BringCarryUnload_START_AT_LOCATION_THEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'BringCarryUnload-START_AT_LOCATION_THEME_INITIAL_LOCATION')
BringCarryUnload_THEME = URIRef(NAMESPACE + 'BringCarryUnload-THEME')
BringCarryUnload_VOLITIONAL_THEME = URIRef(NAMESPACE + 'BringCarryUnload-VOLITIONAL_THEME')
Build = URIRef(NAMESPACE + 'Build')
BuildCreate = URIRef(NAMESPACE + 'BuildCreate')
BuildCreate_AGENT = URIRef(NAMESPACE + 'BuildCreate-AGENT')
BuildCreate_CHANGES_STATE_PATIENT = URIRef(NAMESPACE + 'BuildCreate-CHANGES_STATE_PATIENT')
BuildCreate_CONCRETE_PATIENT = URIRef(NAMESPACE + 'BuildCreate-CONCRETE_PATIENT')
BuildCreate_DESTROYED_PATIENT_ = URIRef(NAMESPACE + 'BuildCreate-DESTROYED_PATIENT-')
BuildCreate_ENTROPY_INCREASE_ = URIRef(NAMESPACE + 'BuildCreate-ENTROPY_INCREASE-')
BuildCreate_INSTR = URIRef(NAMESPACE + 'BuildCreate-INSTR')
BuildCreate_PATIENT = URIRef(NAMESPACE + 'BuildCreate-PATIENT')
BuildCreate_SENTIENT_PATIENT_ = URIRef(NAMESPACE + 'BuildCreate-SENTIENT_PATIENT-')
BuildCreate_SOURCE = URIRef(NAMESPACE + 'BuildCreate-SOURCE')
BuildCreate_VIOLENT_ = URIRef(NAMESPACE + 'BuildCreate-VIOLENT-')
Build_CREATED_PATIENT = URIRef(NAMESPACE + 'Build-CREATED_PATIENT')
Build_PATIENT = URIRef(NAMESPACE + 'Build-PATIENT')
CANDIDATE = URIRef(NAMESPACE + 'CANDIDATE')
CAUSED_BY_POSSIBLE_OR_PAST_EVENT = URIRef(NAMESPACE + 'CAUSED_BY_POSSIBLE_OR_PAST_EVENT')
CAUSER = URIRef(NAMESPACE + 'CAUSER')
CHANGES_LOCATION_ADJUDICATOR_ = URIRef(NAMESPACE + 'CHANGES_LOCATION_ADJUDICATOR-')
CHANGES_LOCATION_AGENT_ = URIRef(NAMESPACE + 'CHANGES_LOCATION_AGENT-')
CHANGES_LOCATION_COTHEME = URIRef(NAMESPACE + 'CHANGES_LOCATION_COTHEME')
CHANGES_LOCATION_DEFENDANT = URIRef(NAMESPACE + 'CHANGES_LOCATION_DEFENDANT')
CHANGES_LOCATION_INSTR = URIRef(NAMESPACE + 'CHANGES_LOCATION_INSTR')
CHANGES_LOCATION_PATIENT = URIRef(NAMESPACE + 'CHANGES_LOCATION_PATIENT')
CHANGES_LOCATION_RECIPIENT_ = URIRef(NAMESPACE + 'CHANGES_LOCATION_RECIPIENT-')
CHANGES_LOCATION_THEME = URIRef(NAMESPACE + 'CHANGES_LOCATION_THEME')
CHANGES_STATE_PATIENT = URIRef(NAMESPACE + 'CHANGES_STATE_PATIENT')
CHANGE_OF_RESIDENCE_THEME = URIRef(NAMESPACE + 'CHANGE_OF_RESIDENCE_THEME')
COLOCATED_ADJUDICATOR_DEFENDENT = URIRef(NAMESPACE + 'COLOCATED_ADJUDICATOR_DEFENDENT')
COLOCATED_AGENT_PATIENT = URIRef(NAMESPACE + 'COLOCATED_AGENT_PATIENT')
COLOCATED_AGENT_RECIPIENT = URIRef(NAMESPACE + 'COLOCATED_AGENT_RECIPIENT')
COLOCATED_AGENT_RECIPIENT_ = URIRef(NAMESPACE + 'COLOCATED_AGENT_RECIPIENT-')
COLOCATED_THEME_COTHEME = URIRef(NAMESPACE + 'COLOCATED_THEME_COTHEME')
COLOCATED_THEME_DESTINATION = URIRef(NAMESPACE + 'COLOCATED_THEME_DESTINATION')
COLOCATED_THEME_INSTR = URIRef(NAMESPACE + 'COLOCATED_THEME_INSTR')
COLOCATED_TOPIC_GROUP = URIRef(NAMESPACE + 'COLOCATED_TOPIC_GROUP')
COMMUNICATE_TO_AGENT_PATIENT = URIRef(NAMESPACE + 'COMMUNICATE_TO_AGENT_PATIENT')
COMMUNICATE_TO_AGENT_RECIPIENT = URIRef(NAMESPACE + 'COMMUNICATE_TO_AGENT_RECIPIENT')
COMMUNICATE_TO_RECIPIENT_AGENT = URIRef(NAMESPACE + 'COMMUNICATE_TO_RECIPIENT_AGENT')
COMM_METHOD = URIRef(NAMESPACE + 'COMM_METHOD')
COMM_METHOD_ = URIRef(NAMESPACE + 'COMM_METHOD-')
COMM_ONEWAY = URIRef(NAMESPACE + 'COMM-ONEWAY')
COMM_ONEWAY_ = URIRef(NAMESPACE + 'COMM-ONEWAY-')
CONCRETE_CAUSE = URIRef(NAMESPACE + 'CONCRETE_CAUSE')
CONCRETE_CAUSE_ = URIRef(NAMESPACE + 'CONCRETE_CAUSE-')
CONCRETE_PATIENT = URIRef(NAMESPACE + 'CONCRETE_PATIENT')
COTHEME = URIRef(NAMESPACE + 'COTHEME')
CREATED_PATIENT = URIRef(NAMESPACE + 'CREATED_PATIENT')
CREATED_PATIENT_ = URIRef(NAMESPACE + 'CREATED_PATIENT-')
CREATED_RESULT = URIRef(NAMESPACE + 'CREATED_RESULT')
CREATED_TOPIC = URIRef(NAMESPACE + 'CREATED_TOPIC')
CREATED_TOPIC_ = URIRef(NAMESPACE + 'CREATED_TOPIC-')
CRIME_OR_CAUSE = URIRef(NAMESPACE + 'CRIME_OR_CAUSE')
CROWD_ACTIVITY_GROUP = URIRef(NAMESPACE + 'CROWD_ACTIVITY_GROUP')
CULTURAL_RELIGIOUS = URIRef(NAMESPACE + 'CULTURAL_RELIGIOUS')
CULTURAL_RELIGIOUS_ = URIRef(NAMESPACE + 'CULTURAL_RELIGIOUS-')
Censor = URIRef(NAMESPACE + 'Censor')
Censor_AGENT = URIRef(NAMESPACE + 'Censor-AGENT')
Censor_ALLOW_COMMUNICATION_BENEFICIARY_PATIENT_ = URIRef(NAMESPACE + 'Censor-ALLOW_COMMUNICATION_BENEFICIARY_PATIENT-')
Censor_BENEFICIARY = URIRef(NAMESPACE + 'Censor-BENEFICIARY')
Censor_PATIENT = URIRef(NAMESPACE + 'Censor-PATIENT')
Ceremony_Wedding = URIRef(NAMESPACE + 'Ceremony_Wedding')
Ceremony_Wedding_ACT_AS_LEGAL_AUTHORITY_AGENT = URIRef(NAMESPACE + 'Ceremony_Wedding-ACT_AS_LEGAL_AUTHORITY_AGENT')
Ceremony_Wedding_AGENT = URIRef(NAMESPACE + 'Ceremony_Wedding-AGENT')
Ceremony_Wedding_COLOCATED_TOPIC_GROUP = URIRef(NAMESPACE + 'Ceremony_Wedding-COLOCATED_TOPIC_GROUP')
Ceremony_Wedding_CROWD_ACTIVITY_GROUP = URIRef(NAMESPACE + 'Ceremony_Wedding-CROWD_ACTIVITY_GROUP')
Ceremony_Wedding_GROUP = URIRef(NAMESPACE + 'Ceremony_Wedding-GROUP')
Ceremony_Wedding_INSTIGATES_TOPIC = URIRef(NAMESPACE + 'Ceremony_Wedding-INSTIGATES_TOPIC')
Ceremony_Wedding_LARGE_NUMBERS_GROUP = URIRef(NAMESPACE + 'Ceremony_Wedding-LARGE_NUMBERS_GROUP')
Ceremony_Wedding_MARRIED_AT_E_TOPIC = URIRef(NAMESPACE + 'Ceremony_Wedding-MARRIED_AT_E_TOPIC')
Ceremony_Wedding_MARRIED_AT_START_TOPIC_ = URIRef(NAMESPACE + 'Ceremony_Wedding-MARRIED_AT_START_TOPIC-')
Ceremony_Wedding_MODE_OF_COMMUNICATION_TEXTUAL_ = URIRef(NAMESPACE + 'Ceremony_Wedding-MODE_OF_COMMUNICATION_TEXTUAL-')
Ceremony_Wedding_MODE_OF_COMMUNICATION_VERBAL = URIRef(NAMESPACE + 'Ceremony_Wedding-MODE_OF_COMMUNICATION_VERBAL')
Ceremony_Wedding_POLITICAL_ = URIRef(NAMESPACE + 'Ceremony_Wedding-POLITICAL-')
Ceremony_Wedding_TOPIC = URIRef(NAMESPACE + 'Ceremony_Wedding-TOPIC')
Chargeindict = URIRef(NAMESPACE + 'Chargeindict')
Chargeindict_ADJUDICATOR = URIRef(NAMESPACE + 'Chargeindict-ADJUDICATOR')
Chargeindict_AFTER_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Chargeindict-AFTER_TRIAL_HEARING-')
Chargeindict_BEFORE_TRIAL_HEARING = URIRef(NAMESPACE + 'Chargeindict-BEFORE_TRIAL_HEARING')
Chargeindict_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Chargeindict-CRIME_OR_CAUSE')
Chargeindict_DEFENDANT = URIRef(NAMESPACE + 'Chargeindict-DEFENDANT')
Chargeindict_DURING_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Chargeindict-DURING_TRIAL_HEARING-')
Chargeindict_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Chargeindict-LEGALLY_IMPOSED')
Chargeindict_PROSECUTOR = URIRef(NAMESPACE + 'Chargeindict-PROSECUTOR')
Chargeindict_REPRESENT_ORG_GPE_PROSECUTOR = URIRef(NAMESPACE + 'Chargeindict-REPRESENT_ORG_GPE_PROSECUTOR')
CivilUnrest = URIRef(NAMESPACE + 'CivilUnrest')
CivilUnrest_AGENT = URIRef(NAMESPACE + 'CivilUnrest-AGENT')
CivilUnrest_DISTRIBUTED_AGENT = URIRef(NAMESPACE + 'CivilUnrest-DISTRIBUTED_AGENT')
CivilUnrest_TOPIC = URIRef(NAMESPACE + 'CivilUnrest-TOPIC')
CivilUnrest_VIOLENT = URIRef(NAMESPACE + 'CivilUnrest-VIOLENT')
ColonizeMigrate = URIRef(NAMESPACE + 'ColonizeMigrate')
ColonizeMigrate_CHANGE_OF_RESIDENCE_THEME = URIRef(NAMESPACE + 'ColonizeMigrate-CHANGE_OF_RESIDENCE_THEME')
ColonizeMigrate_DESTINATION = URIRef(NAMESPACE + 'ColonizeMigrate-DESTINATION')
ColonizeMigrate_END_AT_LOCATION_THEME_DESTINATION = URIRef(NAMESPACE + 'ColonizeMigrate-END_AT_LOCATION_THEME_DESTINATION')
ColonizeMigrate_INITIAL_LOCATION = URIRef(NAMESPACE + 'ColonizeMigrate-INITIAL_LOCATION')
ColonizeMigrate_SELF_MOTION_THEME = URIRef(NAMESPACE + 'ColonizeMigrate-SELF_MOTION_THEME')
ColonizeMigrate_START_AT_LOCATION_THEME_DESTINATION_ = URIRef(NAMESPACE + 'ColonizeMigrate-START_AT_LOCATION_THEME_DESTINATION-')
ColonizeMigrate_THEME = URIRef(NAMESPACE + 'ColonizeMigrate-THEME')
CommandOrder = URIRef(NAMESPACE + 'CommandOrder')
CommandOrder_AGENT = URIRef(NAMESPACE + 'CommandOrder-AGENT')
CommandOrder_COMM_ONEWAY = URIRef(NAMESPACE + 'CommandOrder-COMM-ONEWAY')
CommandOrder_DISCUSS_POSSIBLE_ACTION_BY_RECIPIENT = URIRef(NAMESPACE + 'CommandOrder-DISCUSS_POSSIBLE_ACTION_BY_RECIPIENT')
CommandOrder_HAS_INSTITUTIONAL_POWER_OVER_AT_START_AGENT_RECIPIENT = URIRef(NAMESPACE + 'CommandOrder-HAS_INSTITUTIONAL_POWER_OVER_AT_START_AGENT_RECIPIENT')
CommandOrder_RECIPIENT = URIRef(NAMESPACE + 'CommandOrder-RECIPIENT')
CommandOrder_SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'CommandOrder-SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC')
CommandOrder_TOPIC = URIRef(NAMESPACE + 'CommandOrder-TOPIC')
CommitmentPromiseExpressIntent = URIRef(NAMESPACE + 'CommitmentPromiseExpressIntent')
CommitmentPromiseExpressIntent_AGENT = URIRef(NAMESPACE + 'CommitmentPromiseExpressIntent-AGENT')
CommitmentPromiseExpressIntent_COMM_ONEWAY = URIRef(NAMESPACE + 'CommitmentPromiseExpressIntent-COMM-ONEWAY')
CommitmentPromiseExpressIntent_DISCUSS_POSSIBLE_ACTION_BY_AGENT = URIRef(NAMESPACE + 'CommitmentPromiseExpressIntent-DISCUSS_POSSIBLE_ACTION_BY_AGENT')
CommitmentPromiseExpressIntent_THREATEN_VIOLENCE_AGENT_RECIPIENT_ = URIRef(NAMESPACE + 'CommitmentPromiseExpressIntent-THREATEN_VIOLENCE_AGENT_RECIPIENT-')
CommitmentPromiseExpressIntent_TOPIC = URIRef(NAMESPACE + 'CommitmentPromiseExpressIntent-TOPIC')
CommunicateEvent = URIRef(NAMESPACE + 'CommunicateEvent')
CommunicateEvent_AGENT = URIRef(NAMESPACE + 'CommunicateEvent-AGENT')
CommunicateEvent_COMMUNICATE_TO_AGENT_RECIPIENT = URIRef(NAMESPACE + 'CommunicateEvent-COMMUNICATE_TO_AGENT_RECIPIENT')
CommunicateEvent_INSTR = URIRef(NAMESPACE + 'CommunicateEvent-INSTR')
CommunicateEvent_RECIPIENT = URIRef(NAMESPACE + 'CommunicateEvent-RECIPIENT')
CommunicateEvent_TOPIC = URIRef(NAMESPACE + 'CommunicateEvent-TOPIC')
ConflictEvent = URIRef(NAMESPACE + 'ConflictEvent')
ControlEvent = URIRef(NAMESPACE + 'ControlEvent')
Convict = URIRef(NAMESPACE + 'Convict')
Convict_ADJUDICATOR = URIRef(NAMESPACE + 'Convict-ADJUDICATOR')
Convict_BELIEVE_TO_BE_TRUE_ADJUDICATOR_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Convict-BELIEVE_TO_BE_TRUE_ADJUDICATOR_CRIME_OR_CAUSE')
Convict_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Convict-CRIME_OR_CAUSE')
Convict_DEFENDANT = URIRef(NAMESPACE + 'Convict-DEFENDANT')
Convict_ENTAIL_FUTURE_LEGAL_PUNISHMENT = URIRef(NAMESPACE + 'Convict-ENTAIL_FUTURE_LEGAL_PUNISHMENT')
Convict_PROSECUTOR = URIRef(NAMESPACE + 'Convict-PROSECUTOR')
Correspond = URIRef(NAMESPACE + 'Correspond')
Correspond_AGENT = URIRef(NAMESPACE + 'Correspond-AGENT')
Correspond_COLOCATED_AGENT_RECIPIENT_ = URIRef(NAMESPACE + 'Correspond-COLOCATED_AGENT_RECIPIENT-')
Correspond_COMMUNICATE_TO_RECIPIENT_AGENT = URIRef(NAMESPACE + 'Correspond-COMMUNICATE_TO_RECIPIENT_AGENT')
Correspond_COMM_METHOD = URIRef(NAMESPACE + 'Correspond-COMM_METHOD')
Correspond_COMM_ONEWAY_ = URIRef(NAMESPACE + 'Correspond-COMM-ONEWAY-')
Correspond_MODE_OF_COMMUNICATION_TEXTUAL = URIRef(NAMESPACE + 'Correspond-MODE_OF_COMMUNICATION_TEXTUAL')
Correspond_MODE_OF_COMMUNICATION_VERBAL_ = URIRef(NAMESPACE + 'Correspond-MODE_OF_COMMUNICATION_VERBAL-')
Correspond_RECIPIENT = URIRef(NAMESPACE + 'Correspond-RECIPIENT')
Correspond_TOPIC = URIRef(NAMESPACE + 'Correspond-TOPIC')
Coup = URIRef(NAMESPACE + 'Coup')
Coup_AGENT = URIRef(NAMESPACE + 'Coup-AGENT')
Coup_GAINS_POWER_AGENT_PATIENT = URIRef(NAMESPACE + 'Coup-GAINS_POWER_AGENT_PATIENT')
Coup_PATIENT = URIRef(NAMESPACE + 'Coup-PATIENT')
Coup_PHYSICALACTION = URIRef(NAMESPACE + 'Coup-PHYSICALACTION')
Coup_REJECT_LEADERSHIP = URIRef(NAMESPACE + 'Coup-REJECT_LEADERSHIP')
CreateIntellectualProperty = URIRef(NAMESPACE + 'CreateIntellectualProperty')
CreateIntellectualProperty_CREATED_PATIENT = URIRef(NAMESPACE + 'CreateIntellectualProperty-CREATED_PATIENT')
CreateIntellectualProperty_PATIENT = URIRef(NAMESPACE + 'CreateIntellectualProperty-PATIENT')
CreateManufacture = URIRef(NAMESPACE + 'CreateManufacture')
CreateManufacture_AGENT = URIRef(NAMESPACE + 'CreateManufacture-AGENT')
CreateManufacture_CREATED_PATIENT = URIRef(NAMESPACE + 'CreateManufacture-CREATED_PATIENT')
CreateManufacture_INSTR = URIRef(NAMESPACE + 'CreateManufacture-INSTR')
CreateManufacture_PATIENT = URIRef(NAMESPACE + 'CreateManufacture-PATIENT')
CreateManufacture_SOURCE = URIRef(NAMESPACE + 'CreateManufacture-SOURCE')
CyberAttack_General = URIRef(NAMESPACE + 'CyberAttack_General')
CyberAttack_General_AGENT = URIRef(NAMESPACE + 'CyberAttack_General-AGENT')
CyberAttack_General_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'CyberAttack_General-ENTROPY_INCREASE_PATIENT')
CyberAttack_General_INSTR = URIRef(NAMESPACE + 'CyberAttack_General-INSTR')
CyberAttack_General_PATIENT = URIRef(NAMESPACE + 'CyberAttack_General-PATIENT')
CyberAttack_General_TARGET_IS_COMPUTER_SYSTEM = URIRef(NAMESPACE + 'CyberAttack_General-TARGET_IS_COMPUTER_SYSTEM')
CyberAttack_InformationExtraction = URIRef(NAMESPACE + 'CyberAttack_InformationExtraction')
CyberAttack_InformationExtraction_GET_INFO_AGENT_PATIENT = URIRef(NAMESPACE + 'CyberAttack_InformationExtraction-GET_INFO_AGENT_PATIENT')
CyberAttack_InformationExtraction_INSTR = URIRef(NAMESPACE + 'CyberAttack_InformationExtraction-INSTR')
CyberAttack_InformationExtraction_TARGET_IS_COMPUTER_SYSTEM = URIRef(NAMESPACE + 'CyberAttack_InformationExtraction-TARGET_IS_COMPUTER_SYSTEM')
DANGEROUS_INITIAL_LOCATION = URIRef(NAMESPACE + 'DANGEROUS_INITIAL_LOCATION')
DECIDED_BY_ADJUDICATOR = URIRef(NAMESPACE + 'DECIDED_BY_ADJUDICATOR')
DEFENDANT = URIRef(NAMESPACE + 'DEFENDANT')
DESIRES_EVENT_TO_OCCUR_AGENT_PATIENT = URIRef(NAMESPACE + 'DESIRES_EVENT_TO_OCCUR_AGENT_PATIENT')
DESIRE_POSSESSION_AGENT_PATIENT = URIRef(NAMESPACE + 'DESIRE_POSSESSION_AGENT_PATIENT')
DESTINATION = URIRef(NAMESPACE + 'DESTINATION')
DESTROYED_AGENT = URIRef(NAMESPACE + 'DESTROYED_AGENT')
DESTROYED_PATIENT = URIRef(NAMESPACE + 'DESTROYED_PATIENT')
DESTROYED_PATIENT_ = URIRef(NAMESPACE + 'DESTROYED_PATIENT-')
DIRECTLY_OBSERVE_AGENT_PATIENT = URIRef(NAMESPACE + 'DIRECTLY_OBSERVE_AGENT_PATIENT')
DIRECTLY_OBSERVE_AGENT_PATIENT_ = URIRef(NAMESPACE + 'DIRECTLY_OBSERVE_AGENT_PATIENT-')
DISCUSS_POSSIBLE_ACTION_BY_AGENT = URIRef(NAMESPACE + 'DISCUSS_POSSIBLE_ACTION_BY_AGENT')
DISCUSS_POSSIBLE_ACTION_BY_RECIPIENT = URIRef(NAMESPACE + 'DISCUSS_POSSIBLE_ACTION_BY_RECIPIENT')
DISPERSED_AGENT_ = URIRef(NAMESPACE + 'DISPERSED_AGENT-')
DISPERSED_GROUP_ = URIRef(NAMESPACE + 'DISPERSED_GROUP-')
DISTRIBUTED_AGENT = URIRef(NAMESPACE + 'DISTRIBUTED_AGENT')
DISTRIBUTED_RECIPROCAL_AGENT = URIRef(NAMESPACE + 'DISTRIBUTED_RECIPROCAL_AGENT')
DISTRIBUTED_THEME = URIRef(NAMESPACE + 'DISTRIBUTED_THEME')
DONOR = URIRef(NAMESPACE + 'DONOR')
DURING_TRIAL_HEARING = URIRef(NAMESPACE + 'DURING_TRIAL_HEARING')
DURING_TRIAL_HEARING_ = URIRef(NAMESPACE + 'DURING_TRIAL_HEARING-')
Damage = URIRef(NAMESPACE + 'Damage')
Damage_AGENT = URIRef(NAMESPACE + 'Damage-AGENT')
Damage_DESTROYED_PATIENT_ = URIRef(NAMESPACE + 'Damage-DESTROYED_PATIENT-')
Damage_INSTR = URIRef(NAMESPACE + 'Damage-INSTR')
Damage_PATIENT = URIRef(NAMESPACE + 'Damage-PATIENT')
Damage_VIOLENT = URIRef(NAMESPACE + 'Damage-VIOLENT')
DeathCausedByViolentEvents = URIRef(NAMESPACE + 'DeathCausedByViolentEvents')
DeathCausedByViolentEvents_CHANGES_STATE_PATIENT = URIRef(NAMESPACE + 'DeathCausedByViolentEvents-CHANGES_STATE_PATIENT')
DeathCausedByViolentEvents_DESTROYED_PATIENT = URIRef(NAMESPACE + 'DeathCausedByViolentEvents-DESTROYED_PATIENT')
DeathCausedByViolentEvents_INSTR = URIRef(NAMESPACE + 'DeathCausedByViolentEvents-INSTR')
DeathCausedByViolentEvents_PATIENT = URIRef(NAMESPACE + 'DeathCausedByViolentEvents-PATIENT')
DeathCausedByViolentEvents_PERSONAL_LIFE_EVENT_PATIENT = URIRef(NAMESPACE + 'DeathCausedByViolentEvents-PERSONAL_LIFE_EVENT_PATIENT')
DeathCausedByViolentEvents_VIOLENT = URIRef(NAMESPACE + 'DeathCausedByViolentEvents-VIOLENT')
DeathInjury = URIRef(NAMESPACE + 'DeathInjury')
DeathInjury_AGENT = URIRef(NAMESPACE + 'DeathInjury-AGENT')
DeathInjury_CONCRETE_PATIENT = URIRef(NAMESPACE + 'DeathInjury-CONCRETE_PATIENT')
DeathInjury_CREATED_PATIENT_ = URIRef(NAMESPACE + 'DeathInjury-CREATED_PATIENT-')
DeathInjury_ENTROPY_INCREASE = URIRef(NAMESPACE + 'DeathInjury-ENTROPY_INCREASE')
DeathInjury_INSTR = URIRef(NAMESPACE + 'DeathInjury-INSTR')
DeathInjury_PATIENT = URIRef(NAMESPACE + 'DeathInjury-PATIENT')
DeathInjury_SENTIENT_PATIENT = URIRef(NAMESPACE + 'DeathInjury-SENTIENT_PATIENT')
DeclareSentence = URIRef(NAMESPACE + 'DeclareSentence')
DeclareSentence_ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR = URIRef(NAMESPACE + 'DeclareSentence-ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR')
DeclareSentence_ADJUDICATOR = URIRef(NAMESPACE + 'DeclareSentence-ADJUDICATOR')
DeclareSentence_BELIEVE_TO_BE_TRUE_Adjudicator_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'DeclareSentence-BELIEVE_TO_BE_TRUE_Adjudicator_CRIME_OR_CAUSE')
DeclareSentence_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'DeclareSentence-CRIME_OR_CAUSE')
DeclareSentence_DEFENDANT = URIRef(NAMESPACE + 'DeclareSentence-DEFENDANT')
DeclareSentence_ENTAILS_A_FINANCIAL_PUNISHMENT_ = URIRef(NAMESPACE + 'DeclareSentence-ENTAILS_A_FINANCIAL_PUNISHMENT-')
DeclareSentence_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'DeclareSentence-LEGALLY_IMPOSED')
DeclareSentence_LEGAL_ACTION = URIRef(NAMESPACE + 'DeclareSentence-LEGAL_ACTION')
DeclareSentence_OCCUR_BEFORE_ADJUDICATION_ = URIRef(NAMESPACE + 'DeclareSentence-OCCUR_BEFORE_ADJUDICATION-')
DeclareSentence_PROSECUTOR = URIRef(NAMESPACE + 'DeclareSentence-PROSECUTOR')
DeclareSentence_SENTENCE = URIRef(NAMESPACE + 'DeclareSentence-SENTENCE')
Declare_Bankruptcy = URIRef(NAMESPACE + 'Declare_Bankruptcy')
Declare_Bankruptcy_AGENT = URIRef(NAMESPACE + 'Declare_Bankruptcy-AGENT')
Declare_Bankruptcy_BUSINESS = URIRef(NAMESPACE + 'Declare_Bankruptcy-BUSINESS')
Declare_Bankruptcy_ENTER_BANKRUPTCY_PATIENT = URIRef(NAMESPACE + 'Declare_Bankruptcy-ENTER_BANKRUPTCY_PATIENT')
Declare_Bankruptcy_FAMILY_MARITAL_ = URIRef(NAMESPACE + 'Declare_Bankruptcy-FAMILY_MARITAL-')
Declare_Bankruptcy_INSTIGATES_AGENT = URIRef(NAMESPACE + 'Declare_Bankruptcy-INSTIGATES_AGENT')
Declare_Bankruptcy_PATIENT = URIRef(NAMESPACE + 'Declare_Bankruptcy-PATIENT')
Depart = URIRef(NAMESPACE + 'Depart')
Depart_COTHEME = URIRef(NAMESPACE + 'Depart-COTHEME')
Depart_DESTINATION = URIRef(NAMESPACE + 'Depart-DESTINATION')
Depart_SELF_MOTION_THEME = URIRef(NAMESPACE + 'Depart-SELF_MOTION_THEME')
Depart_START_AT_LOCATION_THEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'Depart-START_AT_LOCATION_THEME_INITIAL_LOCATION')
Depart_THEME = URIRef(NAMESPACE + 'Depart-THEME')
Deport = URIRef(NAMESPACE + 'Deport')
Deport_AGENT = URIRef(NAMESPACE + 'Deport-AGENT')
Deport_CHANGES_LOCATION_AGENT_ = URIRef(NAMESPACE + 'Deport-CHANGES_LOCATION_AGENT-')
Deport_CHANGE_OF_RESIDENCE_THEME = URIRef(NAMESPACE + 'Deport-CHANGE_OF_RESIDENCE_THEME')
Deport_DESTINATION = URIRef(NAMESPACE + 'Deport-DESTINATION')
Deport_END_AT_LOCATION_AGENT_INITIAL_LOCATION = URIRef(NAMESPACE + 'Deport-END_AT_LOCATION_AGENT_INITIAL_LOCATION')
Deport_END_AT_LOCATION_THEME_DESTINATION = URIRef(NAMESPACE + 'Deport-END_AT_LOCATION_THEME_DESTINATION')
Deport_INITIAL_LOCATION = URIRef(NAMESPACE + 'Deport-INITIAL_LOCATION')
Deport_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Deport-LEGALLY_IMPOSED')
Deport_SELF_MOTION_THEME_ = URIRef(NAMESPACE + 'Deport-SELF_MOTION_THEME-')
Deport_START_AT_LOCATION_AGENT_INITIAL_LOCATION = URIRef(NAMESPACE + 'Deport-START_AT_LOCATION_AGENT_INITIAL_LOCATION')
Deport_START_AT_LOCATION_THEME_DESTINATION_ = URIRef(NAMESPACE + 'Deport-START_AT_LOCATION_THEME_DESTINATION-')
Deport_START_AT_LOCATION_THEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'Deport-START_AT_LOCATION_THEME_INITIAL_LOCATION')
Deport_THEME = URIRef(NAMESPACE + 'Deport-THEME')
Deport_VOLITIONAL_THEME_ = URIRef(NAMESPACE + 'Deport-VOLITIONAL_THEME-')
Desire_Possesion = URIRef(NAMESPACE + 'Desire_Possesion')
Desire_Possesion_AGENT = URIRef(NAMESPACE + 'Desire_Possesion-AGENT')
Desire_Possesion_DESIRE_POSSESSION_AGENT_PATIENT = URIRef(NAMESPACE + 'Desire_Possesion-DESIRE_POSSESSION_AGENT_PATIENT')
Desire_Possesion_PATIENT = URIRef(NAMESPACE + 'Desire_Possesion-PATIENT')
Destroy = URIRef(NAMESPACE + 'Destroy')
Destroy_AGENT = URIRef(NAMESPACE + 'Destroy-AGENT')
Destroy_DESTROYED_PATIENT = URIRef(NAMESPACE + 'Destroy-DESTROYED_PATIENT')
Destroy_INSTR = URIRef(NAMESPACE + 'Destroy-INSTR')
Destroy_PATIENT = URIRef(NAMESPACE + 'Destroy-PATIENT')
Destroy_VIOLENT = URIRef(NAMESPACE + 'Destroy-VIOLENT')
Directed_PerformanceParadeSportingEvent = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent')
Directed_PerformanceParadeSportingEvent_AGENT = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-AGENT')
Directed_PerformanceParadeSportingEvent_COLOCATED_TOPIC_GROUP = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-COLOCATED_TOPIC_GROUP')
Directed_PerformanceParadeSportingEvent_CROWD_ACTIVITY_GROUP = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-CROWD_ACTIVITY_GROUP')
Directed_PerformanceParadeSportingEvent_CULTURAL_RELIGIOUS_ = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-CULTURAL_RELIGIOUS-')
Directed_PerformanceParadeSportingEvent_GET_INFO_GROUP_TOPIC = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-GET_INFO_GROUP_TOPIC')
Directed_PerformanceParadeSportingEvent_GROUP = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-GROUP')
Directed_PerformanceParadeSportingEvent_INSTIGATES_AGENT = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-INSTIGATES_AGENT')
Directed_PerformanceParadeSportingEvent_LARGE_NUMBERS_GROUP = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-LARGE_NUMBERS_GROUP')
Directed_PerformanceParadeSportingEvent_POLITICAL_ = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-POLITICAL-')
Directed_PerformanceParadeSportingEvent_TOPIC = URIRef(NAMESPACE + 'Directed_PerformanceParadeSportingEvent-TOPIC')
Disaster = URIRef(NAMESPACE + 'Disaster')
DisasterEvent = URIRef(NAMESPACE + 'DisasterEvent')
Disaster_CAUSER = URIRef(NAMESPACE + 'Disaster-CAUSER')
Disaster_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'Disaster-ENTROPY_INCREASE_PATIENT')
Disaster_PATIENT = URIRef(NAMESPACE + 'Disaster-PATIENT')
Disaster_VOLITIONAL_ = URIRef(NAMESPACE + 'Disaster-VOLITIONAL-')
Discussion = URIRef(NAMESPACE + 'Discussion')
Discussion_AGENT = URIRef(NAMESPACE + 'Discussion-AGENT')
Discussion_COLOCATED_AGENT_RECIPIENT = URIRef(NAMESPACE + 'Discussion-COLOCATED_AGENT_RECIPIENT')
Discussion_COMMUNICATE_TO_RECIPIENT_AGENT = URIRef(NAMESPACE + 'Discussion-COMMUNICATE_TO_RECIPIENT_AGENT')
Discussion_COMM_METHOD_ = URIRef(NAMESPACE + 'Discussion-COMM_METHOD-')
Discussion_COMM_ONEWAY_ = URIRef(NAMESPACE + 'Discussion-COMM-ONEWAY-')
Discussion_MODE_OF_COMMUNICATION_TEXTUAL_ = URIRef(NAMESPACE + 'Discussion-MODE_OF_COMMUNICATION_TEXTUAL-')
Discussion_MODE_OF_COMMUNICATION_VERBAL = URIRef(NAMESPACE + 'Discussion-MODE_OF_COMMUNICATION_VERBAL')
Discussion_RECIPIENT = URIRef(NAMESPACE + 'Discussion-RECIPIENT')
Discussion_TOPIC = URIRef(NAMESPACE + 'Discussion-TOPIC')
Dismantle = URIRef(NAMESPACE + 'Dismantle')
Dismantle_AGENT = URIRef(NAMESPACE + 'Dismantle-AGENT')
Dismantle_DESTROYED_PATIENT_ = URIRef(NAMESPACE + 'Dismantle-DESTROYED_PATIENT-')
Dismantle_INSTIGATES_AGENT = URIRef(NAMESPACE + 'Dismantle-INSTIGATES_AGENT')
Dismantle_INSTR = URIRef(NAMESPACE + 'Dismantle-INSTR')
Dismantle_PATIENT = URIRef(NAMESPACE + 'Dismantle-PATIENT')
Dismantle_VIOLENT_ = URIRef(NAMESPACE + 'Dismantle-VIOLENT-')
DisperseSeparate = URIRef(NAMESPACE + 'DisperseSeparate')
DisperseSeparate_DISTRIBUTED_THEME = URIRef(NAMESPACE + 'DisperseSeparate-DISTRIBUTED_THEME')
DisperseSeparate_THEME = URIRef(NAMESPACE + 'DisperseSeparate-THEME')
Divorce = URIRef(NAMESPACE + 'Divorce')
Divorce_ACT_AS_LEGAL_AUTHORITY_AGENT = URIRef(NAMESPACE + 'Divorce-ACT_AS_LEGAL_AUTHORITY_AGENT')
Divorce_AGENT = URIRef(NAMESPACE + 'Divorce-AGENT')
Divorce_BUSINESS_ = URIRef(NAMESPACE + 'Divorce-BUSINESS-')
Divorce_FAMILY_MARITAL = URIRef(NAMESPACE + 'Divorce-FAMILY_MARITAL')
Divorce_MARRIED_AT_END_PATIENT_ = URIRef(NAMESPACE + 'Divorce-MARRIED_AT_END_PATIENT-')
Divorce_MARRIED_AT_START_PATIENT = URIRef(NAMESPACE + 'Divorce-MARRIED_AT_START_PATIENT')
Divorce_PATIENT = URIRef(NAMESPACE + 'Divorce-PATIENT')
Divorce_PERSONAL_LIFE_EVENT_PATIENT = URIRef(NAMESPACE + 'Divorce-PERSONAL_LIFE_EVENT_PATIENT')
Divorce_VOLITIONAL_AGENT = URIRef(NAMESPACE + 'Divorce-VOLITIONAL_AGENT')
Divorce_VOLITIONAL_PATIENT = URIRef(NAMESPACE + 'Divorce-VOLITIONAL_PATIENT')
Downing = URIRef(NAMESPACE + 'Downing')
Downing_AGENT = URIRef(NAMESPACE + 'Downing-AGENT')
Downing_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'Downing-ATTEMPT_HARM_AGENT_PATIENT')
Downing_DESTROYED_PATIENT = URIRef(NAMESPACE + 'Downing-DESTROYED_PATIENT')
Downing_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'Downing-ENTROPY_INCREASE_PATIENT')
Downing_PATIENT = URIRef(NAMESPACE + 'Downing-PATIENT')
Downing_PHYSICALACTION = URIRef(NAMESPACE + 'Downing-PHYSICALACTION')
Downing_POLITICAL_ = URIRef(NAMESPACE + 'Downing-POLITICAL-')
Downing_VIOLENT = URIRef(NAMESPACE + 'Downing-VIOLENT')
EMPLOYEE = URIRef(NAMESPACE + 'EMPLOYEE')
EMPLOYER = URIRef(NAMESPACE + 'EMPLOYER')
ENACT_ADJUDICATOR_TOPIC = URIRef(NAMESPACE + 'ENACT_ADJUDICATOR_TOPIC')
ENACT_ADJUDICATOR_TOPIC_ = URIRef(NAMESPACE + 'ENACT_ADJUDICATOR_TOPIC-')
END_AT_EVENT_THEME_DESTINATION = URIRef(NAMESPACE + 'END_AT_EVENT_THEME_DESTINATION')
END_AT_LOCATION_ADJUDICATOR_DESTINATION = URIRef(NAMESPACE + 'END_AT_LOCATION_ADJUDICATOR_DESTINATION')
END_AT_LOCATION_AGENT_INITIAL_LOCATION = URIRef(NAMESPACE + 'END_AT_LOCATION_AGENT_INITIAL_LOCATION')
END_AT_LOCATION_COTHEME_DESTINATION = URIRef(NAMESPACE + 'END_AT_LOCATION_COTHEME_DESTINATION')
END_AT_LOCATION_DEFENDANT_DESTINATION = URIRef(NAMESPACE + 'END_AT_LOCATION_DEFENDANT_DESTINATION')
END_AT_LOCATION_PATIENT_INITIAL_LOCATION_ = URIRef(NAMESPACE + 'END_AT_LOCATION_PATIENT_INITIAL_LOCATION-')
END_AT_LOCATION_RECIPIENT_DESTINATION = URIRef(NAMESPACE + 'END_AT_LOCATION_RECIPIENT_DESTINATION')
END_AT_LOCATION_THEME_DESTINATION = URIRef(NAMESPACE + 'END_AT_LOCATION_THEME_DESTINATION')
END_AT_LOCATION_THEME_DESTINATION_ = URIRef(NAMESPACE + 'END_AT_LOCATION_THEME_DESTINATION-')
ENTAILS_A_FINANCIAL_PUNISHMENT = URIRef(NAMESPACE + 'ENTAILS_A_FINANCIAL_PUNISHMENT')
ENTAILS_A_FINANCIAL_PUNISHMENT_ = URIRef(NAMESPACE + 'ENTAILS_A_FINANCIAL_PUNISHMENT-')
ENTAIL_FUTURE_JUDICIAL_DECISION = URIRef(NAMESPACE + 'ENTAIL_FUTURE_JUDICIAL_DECISION')
ENTAIL_FUTURE_LEGAL_PUNISHMENT = URIRef(NAMESPACE + 'ENTAIL_FUTURE_LEGAL_PUNISHMENT')
ENTAIL_FUTURE_LEGAL_PUNISHMENT_ = URIRef(NAMESPACE + 'ENTAIL_FUTURE_LEGAL_PUNISHMENT-')
ENTER_BANKRUPTCY_PATIENT = URIRef(NAMESPACE + 'ENTER_BANKRUPTCY_PATIENT')
ENTROPY_INCREASE = URIRef(NAMESPACE + 'ENTROPY_INCREASE')
ENTROPY_INCREASE_ = URIRef(NAMESPACE + 'ENTROPY_INCREASE-')
ENTROPY_INCREASE_AGENT = URIRef(NAMESPACE + 'ENTROPY_INCREASE_AGENT')
ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'ENTROPY_INCREASE_PATIENT')
EXPRESS_FAVOR_FOR_VOTER_CANDIDATE = URIRef(NAMESPACE + 'EXPRESS_FAVOR_FOR_VOTER_CANDIDATE')
EXPRESS_FAVOR_FOR_VOTER_CANDIDATE_ = URIRef(NAMESPACE + 'EXPRESS_FAVOR_FOR_VOTER_CANDIDATE-')
Economic_Political_ActionsBoycott = URIRef(NAMESPACE + 'Economic_Political_ActionsBoycott')
Economic_Political_ActionsBoycott_AGENT = URIRef(NAMESPACE + 'Economic_Political_ActionsBoycott-AGENT')
Economic_Political_ActionsBoycott_ALLOWED_TO_PARTICIPATE_IN_CHANGE_OF_POSSESSION_PATIENT_ = URIRef(NAMESPACE + 'Economic_Political_ActionsBoycott-ALLOWED_TO_PARTICIPATE_IN_CHANGE_OF_POSSESSION_PATIENT-')
Economic_Political_ActionsBoycott_LARGE_NUMBERS_AGENT = URIRef(NAMESPACE + 'Economic_Political_ActionsBoycott-LARGE_NUMBERS_AGENT')
Economic_Political_ActionsBoycott_PATIENT = URIRef(NAMESPACE + 'Economic_Political_ActionsBoycott-PATIENT')
Economic_Political_ActionsBoycott_TOPIC = URIRef(NAMESPACE + 'Economic_Political_ActionsBoycott-TOPIC')
EmbargoSanction = URIRef(NAMESPACE + 'EmbargoSanction')
EmbargoSanction_AGENT = URIRef(NAMESPACE + 'EmbargoSanction-AGENT')
EmbargoSanction_ALLOW_CHANGE_OF_POSS_PATIENT_ = URIRef(NAMESPACE + 'EmbargoSanction-ALLOW_CHANGE_OF_POSS_PATIENT-')
EmbargoSanction_BENEFICIARY = URIRef(NAMESPACE + 'EmbargoSanction-BENEFICIARY')
EmbargoSanction_PATIENT = URIRef(NAMESPACE + 'EmbargoSanction-PATIENT')
Enable_Action = URIRef(NAMESPACE + 'Enable_Action')
Enable_Action_AGENT = URIRef(NAMESPACE + 'Enable_Action-AGENT')
Enable_Action_ALLOW = URIRef(NAMESPACE + 'Enable_Action-ALLOW')
Enable_Action_BENEFICIARY = URIRef(NAMESPACE + 'Enable_Action-BENEFICIARY')
Enable_Action_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Enable_Action-LEGALLY_IMPOSED')
Enable_Action_PATIENT = URIRef(NAMESPACE + 'Enable_Action-PATIENT')
Enable_Exit = URIRef(NAMESPACE + 'Enable_Exit')
Enable_Exit_AGENT = URIRef(NAMESPACE + 'Enable_Exit-AGENT')
Enable_Exit_ALLOW = URIRef(NAMESPACE + 'Enable_Exit-ALLOW')
Enable_Exit_ALLOW_EXIT = URIRef(NAMESPACE + 'Enable_Exit-ALLOW_EXIT')
Enable_Exit_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Enable_Exit-CRIME_OR_CAUSE')
Enable_Exit_PATIENT = URIRef(NAMESPACE + 'Enable_Exit-PATIENT')
Enable_Exit_PLACE = URIRef(NAMESPACE + 'Enable_Exit-PLACE')
EnactByBallot = URIRef(NAMESPACE + 'EnactByBallot')
EnactByBallot_ADJUDICATE = URIRef(NAMESPACE + 'EnactByBallot-ADJUDICATE')
EnactByBallot_ADJUDICATOR = URIRef(NAMESPACE + 'EnactByBallot-ADJUDICATOR')
EnactByBallot_CREATED_RESULT = URIRef(NAMESPACE + 'EnactByBallot-CREATED_RESULT')
EnactByBallot_ENACT_ADJUDICATOR_TOPIC = URIRef(NAMESPACE + 'EnactByBallot-ENACT_ADJUDICATOR_TOPIC')
EnactByBallot_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'EnactByBallot-LEGALLY_IMPOSED')
EnactByBallot_PUBLIC_VOTE = URIRef(NAMESPACE + 'EnactByBallot-PUBLIC_VOTE')
EnactByBallot_RESULT = URIRef(NAMESPACE + 'EnactByBallot-RESULT')
EnactByBallot_TOPIC = URIRef(NAMESPACE + 'EnactByBallot-TOPIC')
EndOrg = URIRef(NAMESPACE + 'EndOrg')
EndOrg_AGENT = URIRef(NAMESPACE + 'EndOrg-AGENT')
EndOrg_BUSINESS = URIRef(NAMESPACE + 'EndOrg-BUSINESS')
EndOrg_DESTROYED_PATIENT = URIRef(NAMESPACE + 'EndOrg-DESTROYED_PATIENT')
EndOrg_FAMILY_MARITAL_ = URIRef(NAMESPACE + 'EndOrg-FAMILY_MARITAL-')
EndOrg_INSTIGATES_AGENT = URIRef(NAMESPACE + 'EndOrg-INSTIGATES_AGENT')
EndOrg_PATIENT = URIRef(NAMESPACE + 'EndOrg-PATIENT')
Evacuation = URIRef(NAMESPACE + 'Evacuation')
Evacuation_AGENT = URIRef(NAMESPACE + 'Evacuation-AGENT')
Evacuation_ALLOW_EXIT = URIRef(NAMESPACE + 'Evacuation-ALLOW_EXIT')
Evacuation_CHANGES_LOCATION_PATIENT = URIRef(NAMESPACE + 'Evacuation-CHANGES_LOCATION_PATIENT')
Evacuation_END_AT_LOCATION_PATIENT_INITIAL_LOCATION_ = URIRef(NAMESPACE + 'Evacuation-END_AT_LOCATION_PATIENT_INITIAL_LOCATION-')
Evacuation_PATIENT = URIRef(NAMESPACE + 'Evacuation-PATIENT')
Evacuation_TOPIC = URIRef(NAMESPACE + 'Evacuation-TOPIC')
Event = URIRef(NAMESPACE + 'Event')
EventFeatureInstance = URIRef(NAMESPACE + 'EventFeatureInstance')
EventRoleInstance = URIRef(NAMESPACE + 'EventRoleInstance')
Execute = URIRef(NAMESPACE + 'Execute')
Execute_ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR = URIRef(NAMESPACE + 'Execute-ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR')
Execute_AGENT = URIRef(NAMESPACE + 'Execute-AGENT')
Execute_CHANGES_STATE_PATIENT = URIRef(NAMESPACE + 'Execute-CHANGES_STATE_PATIENT')
Execute_CREATED_PATIENT_ = URIRef(NAMESPACE + 'Execute-CREATED_PATIENT-')
Execute_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Execute-CRIME_OR_CAUSE')
Execute_DESTROYED_PATIENT = URIRef(NAMESPACE + 'Execute-DESTROYED_PATIENT')
Execute_ENTROPY_INCREASE = URIRef(NAMESPACE + 'Execute-ENTROPY_INCREASE')
Execute_INSTR = URIRef(NAMESPACE + 'Execute-INSTR')
Execute_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Execute-LEGALLY_IMPOSED')
Execute_LEGAL_ACTION = URIRef(NAMESPACE + 'Execute-LEGAL_ACTION')
Execute_OCCUR_BEFORE_ADJUDICATION_ = URIRef(NAMESPACE + 'Execute-OCCUR_BEFORE_ADJUDICATION-')
Execute_PATIENT = URIRef(NAMESPACE + 'Execute-PATIENT')
Exit_Larger_Organization = URIRef(NAMESPACE + 'Exit_Larger_Organization')
Exit_Larger_Organization_BUSINESS_ = URIRef(NAMESPACE + 'Exit_Larger_Organization-BUSINESS-')
Exit_Larger_Organization_EMPLOYEE = URIRef(NAMESPACE + 'Exit_Larger_Organization-EMPLOYEE')
Exit_Larger_Organization_EMPLOYER = URIRef(NAMESPACE + 'Exit_Larger_Organization-EMPLOYER')
Exit_Larger_Organization_LOSE_POWER_OVER_EMPLOYER_EMPLOYEE = URIRef(NAMESPACE + 'Exit_Larger_Organization-LOSE_POWER_OVER_EMPLOYER_EMPLOYEE')
Exit_Larger_Organization_POLITICAL = URIRef(NAMESPACE + 'Exit_Larger_Organization-POLITICAL')
Exit_Larger_Organization_POSITION = URIRef(NAMESPACE + 'Exit_Larger_Organization-POSITION')
Express_SentimentSide = URIRef(NAMESPACE + 'Express_SentimentSide')
Express_SentimentSide_AFFILIATED_WITH_OPINION_SIDE_AGENT_TOPIC = URIRef(NAMESPACE + 'Express_SentimentSide-AFFILIATED_WITH_OPINION_SIDE_AGENT_TOPIC')
Express_SentimentSide_AGENT = URIRef(NAMESPACE + 'Express_SentimentSide-AGENT')
Express_SentimentSide_COMM_ONEWAY = URIRef(NAMESPACE + 'Express_SentimentSide-COMM-ONEWAY')
Express_SentimentSide_RECIPIENT = URIRef(NAMESPACE + 'Express_SentimentSide-RECIPIENT')
Express_SentimentSide_SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'Express_SentimentSide-SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC')
Express_SentimentSide_TOPIC = URIRef(NAMESPACE + 'Express_SentimentSide-TOPIC')
Extradite = URIRef(NAMESPACE + 'Extradite')
Extradite_ADJUDICATOR = URIRef(NAMESPACE + 'Extradite-ADJUDICATOR')
Extradite_CHANGES_LOCATION_ADJUDICATOR_ = URIRef(NAMESPACE + 'Extradite-CHANGES_LOCATION_ADJUDICATOR-')
Extradite_CHANGES_LOCATION_DEFENDANT = URIRef(NAMESPACE + 'Extradite-CHANGES_LOCATION_DEFENDANT')
Extradite_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Extradite-CRIME_OR_CAUSE')
Extradite_DEFENDANT = URIRef(NAMESPACE + 'Extradite-DEFENDANT')
Extradite_DESTINATION = URIRef(NAMESPACE + 'Extradite-DESTINATION')
Extradite_END_AT_LOCATION_ADJUDICATOR_DESTINATION = URIRef(NAMESPACE + 'Extradite-END_AT_LOCATION_ADJUDICATOR_DESTINATION')
Extradite_END_AT_LOCATION_DEFENDANT_DESTINATION = URIRef(NAMESPACE + 'Extradite-END_AT_LOCATION_DEFENDANT_DESTINATION')
Extradite_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Extradite-LEGALLY_IMPOSED')
Extradite_START_AT_LOCATION_ADJUDICATOR_DESTINATION = URIRef(NAMESPACE + 'Extradite-START_AT_LOCATION_ADJUDICATOR_DESTINATION')
Extradite_START_AT_LOCATION_DEFENDANT_DESTINATION_ = URIRef(NAMESPACE + 'Extradite-START_AT_LOCATION_DEFENDANT_DESTINATION-')
Extradite_START_AT_LOCATION_DEFENDANT_INITIAL_LOCATION = URIRef(NAMESPACE + 'Extradite-START_AT_LOCATION_DEFENDANT_INITIAL_LOCATION')
Extradite_VOLITIONAL_DEFENDANT_ = URIRef(NAMESPACE + 'Extradite-VOLITIONAL_DEFENDANT-')
ExtralegalCapture = URIRef(NAMESPACE + 'ExtralegalCapture')
ExtralegalCapture_AGENT = URIRef(NAMESPACE + 'ExtralegalCapture-AGENT')
ExtralegalCapture_LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'ExtralegalCapture-LEGALLY_IMPOSED-')
ExtralegalCapture_PATIENT = URIRef(NAMESPACE + 'ExtralegalCapture-PATIENT')
ExtralegalCapture_PLACE = URIRef(NAMESPACE + 'ExtralegalCapture-PLACE')
FAMILY_MARITAL = URIRef(NAMESPACE + 'FAMILY_MARITAL')
FAMILY_MARITAL_ = URIRef(NAMESPACE + 'FAMILY_MARITAL-')
Fall = URIRef(NAMESPACE + 'Fall')
Fall_AGENT = URIRef(NAMESPACE + 'Fall-AGENT')
Fall_DESTINATION = URIRef(NAMESPACE + 'Fall-DESTINATION')
Fall_INITIAL_LOCATION = URIRef(NAMESPACE + 'Fall-INITIAL_LOCATION')
Fall_MOTION_IS_HORIZONAL_ = URIRef(NAMESPACE + 'Fall-MOTION_IS_HORIZONAL-')
Fall_START_AT_LOCATION_THEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'Fall-START_AT_LOCATION_THEME_INITIAL_LOCATION')
Fall_THEME = URIRef(NAMESPACE + 'Fall-THEME')
FaminePlague = URIRef(NAMESPACE + 'FaminePlague')
FaminePlague_CAUSER = URIRef(NAMESPACE + 'FaminePlague-CAUSER')
FaminePlague_HAS_FOOD_WATER_NEED_PATIENT = URIRef(NAMESPACE + 'FaminePlague-HAS_FOOD_WATER_NEED_PATIENT')
FaminePlague_LARGE_NUMBERS_PATIENT = URIRef(NAMESPACE + 'FaminePlague-LARGE_NUMBERS_PATIENT')
FaminePlague_PATIENT = URIRef(NAMESPACE + 'FaminePlague-PATIENT')
FaminePlague_SENTIENT_INSTR_ = URIRef(NAMESPACE + 'FaminePlague-SENTIENT_INSTR-')
Feature = URIRef(NAMESPACE + 'Feature')
Fine = URIRef(NAMESPACE + 'Fine')
Fine_ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR = URIRef(NAMESPACE + 'Fine-ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR')
Fine_ADJUDICATOR = URIRef(NAMESPACE + 'Fine-ADJUDICATOR')
Fine_AFTER_TRIAL_HEARING = URIRef(NAMESPACE + 'Fine-AFTER_TRIAL_HEARING')
Fine_BEFORE_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Fine-BEFORE_TRIAL_HEARING-')
Fine_BELIEVE_TO_BE_TRUE_Adjudicator_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Fine-BELIEVE_TO_BE_TRUE_Adjudicator_CRIME_OR_CAUSE')
Fine_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Fine-CRIME_OR_CAUSE')
Fine_DEFENDANT = URIRef(NAMESPACE + 'Fine-DEFENDANT')
Fine_DURING_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Fine-DURING_TRIAL_HEARING-')
Fine_ENTAILS_A_FINANCIAL_PUNISHMENT = URIRef(NAMESPACE + 'Fine-ENTAILS_A_FINANCIAL_PUNISHMENT')
Fine_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Fine-LEGALLY_IMPOSED')
Fine_LEGAL_ACTION = URIRef(NAMESPACE + 'Fine-LEGAL_ACTION')
Fine_OCCUR_BEFORE_ADJUDICATION_ = URIRef(NAMESPACE + 'Fine-OCCUR_BEFORE_ADJUDICATION-')
Fine_PATIENT = URIRef(NAMESPACE + 'Fine-PATIENT')
Fine_PROSECUTOR = URIRef(NAMESPACE + 'Fine-PROSECUTOR')
Fine_SENTENCE = URIRef(NAMESPACE + 'Fine-SENTENCE')
FireExplosion = URIRef(NAMESPACE + 'FireExplosion')
FireExplosion_CAUSER = URIRef(NAMESPACE + 'FireExplosion-CAUSER')
FireExplosion_PATIENT = URIRef(NAMESPACE + 'FireExplosion-PATIENT')
FirearmAttack = URIRef(NAMESPACE + 'FirearmAttack')
FirearmAttack_AGENT = URIRef(NAMESPACE + 'FirearmAttack-AGENT')
FirearmAttack_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'FirearmAttack-ATTEMPT_HARM_AGENT_PATIENT')
FirearmAttack_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'FirearmAttack-ENTROPY_INCREASE_PATIENT')
FirearmAttack_INSTR = URIRef(NAMESPACE + 'FirearmAttack-INSTR')
FirearmAttack_PATIENT = URIRef(NAMESPACE + 'FirearmAttack-PATIENT')
FirearmAttack_PHYSICALACTION = URIRef(NAMESPACE + 'FirearmAttack-PHYSICALACTION')
FirearmAttack_POLITICAL_ = URIRef(NAMESPACE + 'FirearmAttack-POLITICAL-')
FirearmAttack_PROJECTILE_MANNER = URIRef(NAMESPACE + 'FirearmAttack-PROJECTILE_MANNER')
FirearmAttack_USE_AGENT_INSTR = URIRef(NAMESPACE + 'FirearmAttack-USE_AGENT_INSTR')
FirearmAttack_VIOLENT = URIRef(NAMESPACE + 'FirearmAttack-VIOLENT')
FiringLayoff = URIRef(NAMESPACE + 'FiringLayoff')
FiringLayoff_BUSINESS = URIRef(NAMESPACE + 'FiringLayoff-BUSINESS')
FiringLayoff_EMPLOYEE = URIRef(NAMESPACE + 'FiringLayoff-EMPLOYEE')
FiringLayoff_EMPLOYER = URIRef(NAMESPACE + 'FiringLayoff-EMPLOYER')
FiringLayoff_LOSE_POSITION_EMPLOYEE_POSITION = URIRef(NAMESPACE + 'FiringLayoff-LOSE_POSITION_EMPLOYEE_POSITION')
FiringLayoff_LOSE_POWER_OVER_EMPLOYER_EMPLOYEE = URIRef(NAMESPACE + 'FiringLayoff-LOSE_POWER_OVER_EMPLOYER_EMPLOYEE')
FiringLayoff_POSITION = URIRef(NAMESPACE + 'FiringLayoff-POSITION')
FiringLayoff_VOLITIONAL_EMPLOYEE_ = URIRef(NAMESPACE + 'FiringLayoff-VOLITIONAL_EMPLOYEE-')
FiringLayoff_VOLITIONAL_EMPLOYER = URIRef(NAMESPACE + 'FiringLayoff-VOLITIONAL_EMPLOYER')
Free = URIRef(NAMESPACE + 'Free')
Free_AGENT = URIRef(NAMESPACE + 'Free-AGENT')
Free_LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'Free-LEGALLY_IMPOSED-')
Free_PATIENT = URIRef(NAMESPACE + 'Free-PATIENT')
Free_PLACE = URIRef(NAMESPACE + 'Free-PLACE')
FuneralVigil = URIRef(NAMESPACE + 'FuneralVigil')
FuneralVigil_AGENT = URIRef(NAMESPACE + 'FuneralVigil-AGENT')
FuneralVigil_CROWD_ACTIVITY_GROUP = URIRef(NAMESPACE + 'FuneralVigil-CROWD_ACTIVITY_GROUP')
FuneralVigil_CULTURAL_RELIGIOUS = URIRef(NAMESPACE + 'FuneralVigil-CULTURAL_RELIGIOUS')
FuneralVigil_GROUP = URIRef(NAMESPACE + 'FuneralVigil-GROUP')
FuneralVigil_INSTIGATES_AGENT = URIRef(NAMESPACE + 'FuneralVigil-INSTIGATES_AGENT')
FuneralVigil_IS_DECEASED = URIRef(NAMESPACE + 'FuneralVigil-IS_DECEASED')
FuneralVigil_LARGE_NUMBERS_GROUP = URIRef(NAMESPACE + 'FuneralVigil-LARGE_NUMBERS_GROUP')
FuneralVigil_POLITICAL_ = URIRef(NAMESPACE + 'FuneralVigil-POLITICAL-')
FuneralVigil_TOPIC = URIRef(NAMESPACE + 'FuneralVigil-TOPIC')
GAINS_POWER_AGENT_PATIENT = URIRef(NAMESPACE + 'GAINS_POWER_AGENT_PATIENT')
GAIN_POSITION_CANDIDATE_POSITION = URIRef(NAMESPACE + 'GAIN_POSITION_CANDIDATE_POSITION')
GAIN_POSITION_CANDIDATE_POSITION_ = URIRef(NAMESPACE + 'GAIN_POSITION_CANDIDATE_POSITION-')
GAIN_POSITION_EMPLOYEE_POSITION = URIRef(NAMESPACE + 'GAIN_POSITION_EMPLOYEE_POSITION')
GAIN_POSSESSION_DONOR_ASSET = URIRef(NAMESPACE + 'GAIN_POSSESSION_DONOR_ASSET')
GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'GAIN_POSSESSION_RECIPIENT_PATIENT')
GAIN_POSSESSION_RECIPIENT_THEME = URIRef(NAMESPACE + 'GAIN_POSSESSION_RECIPIENT_THEME')
GAIN_POSSESSION_THEME_DESTINATION = URIRef(NAMESPACE + 'GAIN_POSSESSION_THEME_DESTINATION')
GAIN_POWER_OVER_CANDIDATE_VOTER = URIRef(NAMESPACE + 'GAIN_POWER_OVER_CANDIDATE_VOTER')
GAIN_POWER_OVER_CANDIDATE_VOTER_ = URIRef(NAMESPACE + 'GAIN_POWER_OVER_CANDIDATE_VOTER-')
GAIN_POWER_OVER_EMPLOYER_EMPLOYEE = URIRef(NAMESPACE + 'GAIN_POWER_OVER_EMPLOYER_EMPLOYEE')
GET_INFO_AGENT_PATIENT = URIRef(NAMESPACE + 'GET_INFO_AGENT_PATIENT')
GET_INFO_BENEFICIARY_PATIENT = URIRef(NAMESPACE + 'GET_INFO_BENEFICIARY_PATIENT')
GET_INFO_GROUP_TOPIC = URIRef(NAMESPACE + 'GET_INFO_GROUP_TOPIC')
GROUP = URIRef(NAMESPACE + 'GROUP')
Gain_income = URIRef(NAMESPACE + 'Gain_income')
Gain_income_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'Gain_income-GAIN_POSSESSION_RECIPIENT_PATIENT')
Gain_income_PATIENT = URIRef(NAMESPACE + 'Gain_income-PATIENT')
Gain_income_RECIPIENT = URIRef(NAMESPACE + 'Gain_income-RECIPIENT')
GatheringEvents = URIRef(NAMESPACE + 'GatheringEvents')
GatheringEvents_ADJUDICATOR = URIRef(NAMESPACE + 'GatheringEvents-ADJUDICATOR')
GatheringEvents_AGENT = URIRef(NAMESPACE + 'GatheringEvents-AGENT')
GatheringEvents_DISPERSED_GROUP_ = URIRef(NAMESPACE + 'GatheringEvents-DISPERSED_GROUP-')
GatheringEvents_GROUP = URIRef(NAMESPACE + 'GatheringEvents-GROUP')
GatheringEvents_TOPIC = URIRef(NAMESPACE + 'GatheringEvents-TOPIC')
GeneralCrime = URIRef(NAMESPACE + 'GeneralCrime')
GeneralCrime_AGENT = URIRef(NAMESPACE + 'GeneralCrime-AGENT')
GeneralCrime_IS_CRIME_OR_CRIMINAL = URIRef(NAMESPACE + 'GeneralCrime-IS_CRIME_OR_CRIMINAL')
GenericAttack = URIRef(NAMESPACE + 'GenericAttack')
GenericAttack_AGENT = URIRef(NAMESPACE + 'GenericAttack-AGENT')
GenericAttack_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'GenericAttack-ATTEMPT_HARM_AGENT_PATIENT')
GenericAttack_ATTEMPT_HARM_PATIENT_AGENT = URIRef(NAMESPACE + 'GenericAttack-ATTEMPT_HARM_PATIENT_AGENT')
GenericAttack_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'GenericAttack-ENTROPY_INCREASE_PATIENT')
GenericAttack_PATIENT = URIRef(NAMESPACE + 'GenericAttack-PATIENT')
GenericAttack_PHYSICALACTION = URIRef(NAMESPACE + 'GenericAttack-PHYSICALACTION')
GenericAttack_POLITICAL_ = URIRef(NAMESPACE + 'GenericAttack-POLITICAL-')
GenericAttack_VIOLENT = URIRef(NAMESPACE + 'GenericAttack-VIOLENT')
GenericFight = URIRef(NAMESPACE + 'GenericFight')
GenericFight_AGENT = URIRef(NAMESPACE + 'GenericFight-AGENT')
GenericFight_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'GenericFight-ATTEMPT_HARM_AGENT_PATIENT')
GenericFight_ATTEMPT_HARM_PATIENT_AGENT = URIRef(NAMESPACE + 'GenericFight-ATTEMPT_HARM_PATIENT_AGENT')
GenericFight_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'GenericFight-ENTROPY_INCREASE_PATIENT')
GenericFight_PATIENT = URIRef(NAMESPACE + 'GenericFight-PATIENT')
GenericFight_PHYSICALACTION = URIRef(NAMESPACE + 'GenericFight-PHYSICALACTION')
GenericFight_POLITICAL_ = URIRef(NAMESPACE + 'GenericFight-POLITICAL-')
GenericFight_VIOLENT = URIRef(NAMESPACE + 'GenericFight-VIOLENT')
GiftGrantProvide_Aid = URIRef(NAMESPACE + 'GiftGrantProvide_Aid')
GiftGrantProvide_Aid_DONOR = URIRef(NAMESPACE + 'GiftGrantProvide_Aid-DONOR')
GiftGrantProvide_Aid_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'GiftGrantProvide_Aid-GAIN_POSSESSION_RECIPIENT_PATIENT')
GiftGrantProvide_Aid_IS_CRIME_OR_CRIMINAL_ = URIRef(NAMESPACE + 'GiftGrantProvide_Aid-IS_CRIME_OR_CRIMINAL-')
GiftGrantProvide_Aid_LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'GiftGrantProvide_Aid-LEGALLY_IMPOSED-')
GiftGrantProvide_Aid_LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'GiftGrantProvide_Aid-LOSE_POSSESSION_DONOR_PATIENT')
GiftGrantProvide_Aid_PATIENT = URIRef(NAMESPACE + 'GiftGrantProvide_Aid-PATIENT')
GiftGrantProvide_Aid_RECIPIENT = URIRef(NAMESPACE + 'GiftGrantProvide_Aid-RECIPIENT')
Giving_birth = URIRef(NAMESPACE + 'Giving_birth')
Giving_birth_AGENT = URIRef(NAMESPACE + 'Giving_birth-AGENT')
Giving_birth_CREATED_PATIENT = URIRef(NAMESPACE + 'Giving_birth-CREATED_PATIENT')
Giving_birth_PATIENT = URIRef(NAMESPACE + 'Giving_birth-PATIENT')
Giving_birth_PERSONAL_LIFE_EVENT_PATIENT = URIRef(NAMESPACE + 'Giving_birth-PERSONAL_LIFE_EVENT_PATIENT')
Grant_EntryAsylum = URIRef(NAMESPACE + 'Grant_EntryAsylum')
Grant_EntryAsylum_AGENT = URIRef(NAMESPACE + 'Grant_EntryAsylum-AGENT')
Grant_EntryAsylum_ALLOWED_ENTRY_BENEFICIARY = URIRef(NAMESPACE + 'Grant_EntryAsylum-ALLOWED_ENTRY_BENEFICIARY')
Grant_EntryAsylum_BENEFICIARY = URIRef(NAMESPACE + 'Grant_EntryAsylum-BENEFICIARY')
HAS_FOOD_WATER_NEED_PATIENT = URIRef(NAMESPACE + 'HAS_FOOD_WATER_NEED_PATIENT')
HAS_INSTITUTIONAL_POWER_OVER_AT_START_AGENT_RECIPIENT = URIRef(NAMESPACE + 'HAS_INSTITUTIONAL_POWER_OVER_AT_START_AGENT_RECIPIENT')
HAS_INSTITUTIONAL_POWER_OVER_AT_START_AGENT_RECIPIENT_ = URIRef(NAMESPACE + 'HAS_INSTITUTIONAL_POWER_OVER_AT_START_AGENT_RECIPIENT-')
HAVE_PHYSICAL_CONTROL_OVER_AGENT_PATIENT = URIRef(NAMESPACE + 'HAVE_PHYSICAL_CONTROL_OVER_AGENT_PATIENT')
Hiring = URIRef(NAMESPACE + 'Hiring')
Hiring_BUSINESS = URIRef(NAMESPACE + 'Hiring-BUSINESS')
Hiring_EMPLOYEE = URIRef(NAMESPACE + 'Hiring-EMPLOYEE')
Hiring_EMPLOYER = URIRef(NAMESPACE + 'Hiring-EMPLOYER')
Hiring_GAIN_POSITION_EMPLOYEE_POSITION = URIRef(NAMESPACE + 'Hiring-GAIN_POSITION_EMPLOYEE_POSITION')
Hiring_GAIN_POWER_OVER_EMPLOYER_EMPLOYEE = URIRef(NAMESPACE + 'Hiring-GAIN_POWER_OVER_EMPLOYER_EMPLOYEE')
Hiring_POSITION = URIRef(NAMESPACE + 'Hiring-POSITION')
Hiring_VOLITIONAL_EMPLOYEE = URIRef(NAMESPACE + 'Hiring-VOLITIONAL_EMPLOYEE')
Hiring_VOLITIONAL_EMPLOYER = URIRef(NAMESPACE + 'Hiring-VOLITIONAL_EMPLOYER')
Hold_Election = URIRef(NAMESPACE + 'Hold_Election')
Hold_Election_POSITION = URIRef(NAMESPACE + 'Hold_Election-POSITION')
Hold_Election_PUBLIC_VOTE = URIRef(NAMESPACE + 'Hold_Election-PUBLIC_VOTE')
Hold_Election_RESULT = URIRef(NAMESPACE + 'Hold_Election-RESULT')
Hold_Election_VOTER = URIRef(NAMESPACE + 'Hold_Election-VOTER')
INITIAL_LOCATION = URIRef(NAMESPACE + 'INITIAL_LOCATION')
INSTIGATES_AGENT = URIRef(NAMESPACE + 'INSTIGATES_AGENT')
INSTIGATES_AGENT_ = URIRef(NAMESPACE + 'INSTIGATES_AGENT-')
INSTIGATES_TOPIC = URIRef(NAMESPACE + 'INSTIGATES_TOPIC')
INSTR = URIRef(NAMESPACE + 'INSTR')
IS_CRIME_OR_CRIMINAL = URIRef(NAMESPACE + 'IS_CRIME_OR_CRIMINAL')
IS_CRIME_OR_CRIMINAL_ = URIRef(NAMESPACE + 'IS_CRIME_OR_CRIMINAL-')
IS_CRIME_OR_CRIMINAL_PATIENT = URIRef(NAMESPACE + 'IS_CRIME_OR_CRIMINAL_PATIENT')
IS_CRIME_OR_CRIMINAL_PATIENT_ = URIRef(NAMESPACE + 'IS_CRIME_OR_CRIMINAL_PATIENT-')
IS_DECEASED = URIRef(NAMESPACE + 'IS_DECEASED')
IllnessDegradation_HungerThirst = URIRef(NAMESPACE + 'IllnessDegradation_HungerThirst')
IllnessDegradation_HungerThirst_CONCRETE_CAUSE_ = URIRef(NAMESPACE + 'IllnessDegradation_HungerThirst-CONCRETE_CAUSE-')
IllnessDegradation_HungerThirst_HAS_FOOD_WATER_NEED_PATIENT = URIRef(NAMESPACE + 'IllnessDegradation_HungerThirst-HAS_FOOD_WATER_NEED_PATIENT')
IllnessDegradation_HungerThirst_PATIENT = URIRef(NAMESPACE + 'IllnessDegradation_HungerThirst-PATIENT')
IllnessDegradation_HungerThirst_VIOLENT_ = URIRef(NAMESPACE + 'IllnessDegradation_HungerThirst-VIOLENT-')
IllnessDegradation_Physical = URIRef(NAMESPACE + 'IllnessDegradation_Physical')
IllnessDegradation_Physical_CONCRETE_CAUSE = URIRef(NAMESPACE + 'IllnessDegradation_Physical-CONCRETE_CAUSE')
IllnessDegradation_Physical_DESTROYED_PATIENT_ = URIRef(NAMESPACE + 'IllnessDegradation_Physical-DESTROYED_PATIENT-')
IllnessDegradation_Physical_INSTIGATES_AGENT_ = URIRef(NAMESPACE + 'IllnessDegradation_Physical-INSTIGATES_AGENT-')
IllnessDegradation_Physical_PATIENT = URIRef(NAMESPACE + 'IllnessDegradation_Physical-PATIENT')
IllnessDegradation_Physical_VIOLENT_ = URIRef(NAMESPACE + 'IllnessDegradation_Physical-VIOLENT-')
IllnessDegradation_Sickness = URIRef(NAMESPACE + 'IllnessDegradation_Sickness')
IllnessDegradation_Sickness_CONCRETE_CAUSE_ = URIRef(NAMESPACE + 'IllnessDegradation_Sickness-CONCRETE_CAUSE-')
IllnessDegradation_Sickness_PATIENT = URIRef(NAMESPACE + 'IllnessDegradation_Sickness-PATIENT')
IllnessDegradation_Sickness_VIOLENT_ = URIRef(NAMESPACE + 'IllnessDegradation_Sickness-VIOLENT-')
InitiateJudicialProcess = URIRef(NAMESPACE + 'InitiateJudicialProcess')
InitiateJudicialProcess_ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR = URIRef(NAMESPACE + 'InitiateJudicialProcess-ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR')
InitiateJudicialProcess_ADJUDICATOR = URIRef(NAMESPACE + 'InitiateJudicialProcess-ADJUDICATOR')
InitiateJudicialProcess_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'InitiateJudicialProcess-CRIME_OR_CAUSE')
InitiateJudicialProcess_DEFENDANT = URIRef(NAMESPACE + 'InitiateJudicialProcess-DEFENDANT')
InitiateJudicialProcess_ENTAIL_FUTURE_JUDICIAL_DECISION = URIRef(NAMESPACE + 'InitiateJudicialProcess-ENTAIL_FUTURE_JUDICIAL_DECISION')
InitiateJudicialProcess_LEGAL_ACTION = URIRef(NAMESPACE + 'InitiateJudicialProcess-LEGAL_ACTION')
InitiateJudicialProcess_OCCUR_BEFORE_ADJUDICATION_ = URIRef(NAMESPACE + 'InitiateJudicialProcess-OCCUR_BEFORE_ADJUDICATION-')
InitiateJudicialProcess_PROSECUTOR = URIRef(NAMESPACE + 'InitiateJudicialProcess-PROSECUTOR')
InitiateJudicialProcess_SENTENCE = URIRef(NAMESPACE + 'InitiateJudicialProcess-SENTENCE')
InjureTortureBeatRape = URIRef(NAMESPACE + 'InjureTortureBeatRape')
InjureTortureBeatRape_AGENT = URIRef(NAMESPACE + 'InjureTortureBeatRape-AGENT')
InjureTortureBeatRape_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'InjureTortureBeatRape-ATTEMPT_HARM_AGENT_PATIENT')
InjureTortureBeatRape_DESTROYED_PATIENT_ = URIRef(NAMESPACE + 'InjureTortureBeatRape-DESTROYED_PATIENT-')
InjureTortureBeatRape_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'InjureTortureBeatRape-ENTROPY_INCREASE_PATIENT')
InjureTortureBeatRape_PATIENT = URIRef(NAMESPACE + 'InjureTortureBeatRape-PATIENT')
InjureTortureBeatRape_PHYSICALACTION = URIRef(NAMESPACE + 'InjureTortureBeatRape-PHYSICALACTION')
InjureTortureBeatRape_POLITICAL_ = URIRef(NAMESPACE + 'InjureTortureBeatRape-POLITICAL-')
InjureTortureBeatRape_VIOLENT = URIRef(NAMESPACE + 'InjureTortureBeatRape-VIOLENT')
InjureTortureBeatRape_VOLITIONAL_AGENT = URIRef(NAMESPACE + 'InjureTortureBeatRape-VOLITIONAL_AGENT')
InjuryCausedByViolentEvents = URIRef(NAMESPACE + 'InjuryCausedByViolentEvents')
InjuryCausedByViolentEvents_DESTROYED_PATIENT_ = URIRef(NAMESPACE + 'InjuryCausedByViolentEvents-DESTROYED_PATIENT-')
InjuryCausedByViolentEvents_INSTIGATES_AGENT = URIRef(NAMESPACE + 'InjuryCausedByViolentEvents-INSTIGATES_AGENT')
InjuryCausedByViolentEvents_INSTR = URIRef(NAMESPACE + 'InjuryCausedByViolentEvents-INSTR')
InjuryCausedByViolentEvents_PATIENT = URIRef(NAMESPACE + 'InjuryCausedByViolentEvents-PATIENT')
InjuryCausedByViolentEvents_VIOLENT = URIRef(NAMESPACE + 'InjuryCausedByViolentEvents-VIOLENT')
InspectInvestigateObserveStudy = URIRef(NAMESPACE + 'InspectInvestigateObserveStudy')
InspectInvestigateObserveStudy_AGENT = URIRef(NAMESPACE + 'InspectInvestigateObserveStudy-AGENT')
InspectInvestigateObserveStudy_BENEFICIARY = URIRef(NAMESPACE + 'InspectInvestigateObserveStudy-BENEFICIARY')
InspectInvestigateObserveStudy_INSTR = URIRef(NAMESPACE + 'InspectInvestigateObserveStudy-INSTR')
InspectInvestigateObserveStudy_PATIENT = URIRef(NAMESPACE + 'InspectInvestigateObserveStudy-PATIENT')
InspectInvestigateObserveStudy_TOPIC = URIRef(NAMESPACE + 'InspectInvestigateObserveStudy-TOPIC')
InspectInvestigateObserveStudy_VOLITIONAL_AGENT = URIRef(NAMESPACE + 'InspectInvestigateObserveStudy-VOLITIONAL_AGENT')
InspectPeopleOrganization = URIRef(NAMESPACE + 'InspectPeopleOrganization')
InspectPeopleOrganization_AGENT = URIRef(NAMESPACE + 'InspectPeopleOrganization-AGENT')
InspectPeopleOrganization_AWARE_OF_EVENT_PATIENT = URIRef(NAMESPACE + 'InspectPeopleOrganization-AWARE_OF_EVENT_PATIENT')
InspectPeopleOrganization_COLOCATED_AGENT_PATIENT = URIRef(NAMESPACE + 'InspectPeopleOrganization-COLOCATED_AGENT_PATIENT')
InspectPeopleOrganization_GET_INFO_AGENT_PATIENT = URIRef(NAMESPACE + 'InspectPeopleOrganization-GET_INFO_AGENT_PATIENT')
InspectPeopleOrganization_PATIENT = URIRef(NAMESPACE + 'InspectPeopleOrganization-PATIENT')
IntendDesire = URIRef(NAMESPACE + 'IntendDesire')
IntendDesire_AGENT = URIRef(NAMESPACE + 'IntendDesire-AGENT')
IntendDesire_DESIRES_EVENT_TO_OCCUR_AGENT_PATIENT = URIRef(NAMESPACE + 'IntendDesire-DESIRES_EVENT_TO_OCCUR_AGENT_PATIENT')
IntendDesire_MidLevel = URIRef(NAMESPACE + 'IntendDesire_MidLevel')
IntendDesire_MidLevel_AGENT = URIRef(NAMESPACE + 'IntendDesire_MidLevel-AGENT')
IntendDesire_MidLevel_PATIENT = URIRef(NAMESPACE + 'IntendDesire_MidLevel-PATIENT')
IntendDesire_PATIENT = URIRef(NAMESPACE + 'IntendDesire-PATIENT')
Invade = URIRef(NAMESPACE + 'Invade')
Invade_DESTINATION = URIRef(NAMESPACE + 'Invade-DESTINATION')
Invade_END_AT_EVENT_THEME_DESTINATION = URIRef(NAMESPACE + 'Invade-END_AT_EVENT_THEME_DESTINATION')
Invade_GAIN_POSSESSION_THEME_DESTINATION = URIRef(NAMESPACE + 'Invade-GAIN_POSSESSION_THEME_DESTINATION')
Invade_SELF_MOTION_THEME = URIRef(NAMESPACE + 'Invade-SELF_MOTION_THEME')
Invade_THEME = URIRef(NAMESPACE + 'Invade-THEME')
Invade_VIOLENT = URIRef(NAMESPACE + 'Invade-VIOLENT')
Invade_VOLITIONAL_DESTINATION_ = URIRef(NAMESPACE + 'Invade-VOLITIONAL_DESTINATION-')
Invade_VOLITIONAL_THEME = URIRef(NAMESPACE + 'Invade-VOLITIONAL_THEME')
InvestigateCrime = URIRef(NAMESPACE + 'InvestigateCrime')
InvestigateCrime_AGENT = URIRef(NAMESPACE + 'InvestigateCrime-AGENT')
InvestigateCrime_AWARE_OF_EVENT_PATIENT = URIRef(NAMESPACE + 'InvestigateCrime-AWARE_OF_EVENT_PATIENT')
InvestigateCrime_COLOCATED_AGENT_PATIENT = URIRef(NAMESPACE + 'InvestigateCrime-COLOCATED_AGENT_PATIENT')
InvestigateCrime_GET_INFO_AGENT_PATIENT = URIRef(NAMESPACE + 'InvestigateCrime-GET_INFO_AGENT_PATIENT')
InvestigateCrime_PATIENT = URIRef(NAMESPACE + 'InvestigateCrime-PATIENT')
InvestigateCrime_TOPIC = URIRef(NAMESPACE + 'InvestigateCrime-TOPIC')
Join_Larger_Organization = URIRef(NAMESPACE + 'Join_Larger_Organization')
Join_Larger_Organization_BUSINESS_ = URIRef(NAMESPACE + 'Join_Larger_Organization-BUSINESS-')
Join_Larger_Organization_EMPLOYEE = URIRef(NAMESPACE + 'Join_Larger_Organization-EMPLOYEE')
Join_Larger_Organization_EMPLOYER = URIRef(NAMESPACE + 'Join_Larger_Organization-EMPLOYER')
Join_Larger_Organization_GAIN_POWER_OVER_EMPLOYER_EMPLOYEE = URIRef(NAMESPACE + 'Join_Larger_Organization-GAIN_POWER_OVER_EMPLOYER_EMPLOYEE')
Join_Larger_Organization_POLITICAL = URIRef(NAMESPACE + 'Join_Larger_Organization-POLITICAL')
Join_Larger_Organization_POSITION = URIRef(NAMESPACE + 'Join_Larger_Organization-POSITION')
JudicialConsequences = URIRef(NAMESPACE + 'JudicialConsequences')
JudicialConsequences_ADJUDICATOR = URIRef(NAMESPACE + 'JudicialConsequences-ADJUDICATOR')
JudicialConsequences_AGENT = URIRef(NAMESPACE + 'JudicialConsequences-AGENT')
JudicialConsequences_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'JudicialConsequences-CRIME_OR_CAUSE')
JudicialConsequences_DEFENDANT = URIRef(NAMESPACE + 'JudicialConsequences-DEFENDANT')
JudicialConsequences_DESTINATION = URIRef(NAMESPACE + 'JudicialConsequences-DESTINATION')
JudicialConsequences_INITIAL_LOCATION = URIRef(NAMESPACE + 'JudicialConsequences-INITIAL_LOCATION')
JudicialConsequences_INSTR = URIRef(NAMESPACE + 'JudicialConsequences-INSTR')
JudicialConsequences_PATIENT = URIRef(NAMESPACE + 'JudicialConsequences-PATIENT')
JudicialConsequences_PROSECUTOR = URIRef(NAMESPACE + 'JudicialConsequences-PROSECUTOR')
JudicialConsequences_SENTENCE = URIRef(NAMESPACE + 'JudicialConsequences-SENTENCE')
JudicialFindingOfTruth = URIRef(NAMESPACE + 'JudicialFindingOfTruth')
JudicialFindingOfTruth_ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR = URIRef(NAMESPACE + 'JudicialFindingOfTruth-ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR')
JudicialFindingOfTruth_ADJUDICATOR = URIRef(NAMESPACE + 'JudicialFindingOfTruth-ADJUDICATOR')
JudicialFindingOfTruth_AFTER_TRIAL_HEARING = URIRef(NAMESPACE + 'JudicialFindingOfTruth-AFTER_TRIAL_HEARING')
JudicialFindingOfTruth_BEFORE_TRIAL_HEARING_ = URIRef(NAMESPACE + 'JudicialFindingOfTruth-BEFORE_TRIAL_HEARING-')
JudicialFindingOfTruth_COLOCATED_ADJUDICATOR_DEFENDENT = URIRef(NAMESPACE + 'JudicialFindingOfTruth-COLOCATED_ADJUDICATOR_DEFENDENT')
JudicialFindingOfTruth_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'JudicialFindingOfTruth-CRIME_OR_CAUSE')
JudicialFindingOfTruth_DECIDED_BY_ADJUDICATOR = URIRef(NAMESPACE + 'JudicialFindingOfTruth-DECIDED_BY_ADJUDICATOR')
JudicialFindingOfTruth_DEFENDANT = URIRef(NAMESPACE + 'JudicialFindingOfTruth-DEFENDANT')
JudicialFindingOfTruth_DURING_TRIAL_HEARING_ = URIRef(NAMESPACE + 'JudicialFindingOfTruth-DURING_TRIAL_HEARING-')
JudicialFindingOfTruth_LEGAL_ACTION = URIRef(NAMESPACE + 'JudicialFindingOfTruth-LEGAL_ACTION')
JudicialFindingOfTruth_PROSECUTOR = URIRef(NAMESPACE + 'JudicialFindingOfTruth-PROSECUTOR')
KidnapTakeHostages = URIRef(NAMESPACE + 'KidnapTakeHostages')
KidnapTakeHostages_PATIENT = URIRef(NAMESPACE + 'KidnapTakeHostages-PATIENT')
KidnapTakeHostages_RECIPIENT = URIRef(NAMESPACE + 'KidnapTakeHostages-RECIPIENT')
Kill = URIRef(NAMESPACE + 'Kill')
Kill_AGENT = URIRef(NAMESPACE + 'Kill-AGENT')
Kill_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'Kill-ATTEMPT_HARM_AGENT_PATIENT')
Kill_DESTROYED_PATIENT = URIRef(NAMESPACE + 'Kill-DESTROYED_PATIENT')
Kill_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'Kill-ENTROPY_INCREASE_PATIENT')
Kill_PATIENT = URIRef(NAMESPACE + 'Kill-PATIENT')
Kill_PHYSICALACTION = URIRef(NAMESPACE + 'Kill-PHYSICALACTION')
Kill_POLITICAL_ = URIRef(NAMESPACE + 'Kill-POLITICAL-')
Kill_VIOLENT = URIRef(NAMESPACE + 'Kill-VIOLENT')
LARGE_NUMBERS_AGENT = URIRef(NAMESPACE + 'LARGE_NUMBERS_AGENT')
LARGE_NUMBERS_GROUP = URIRef(NAMESPACE + 'LARGE_NUMBERS_GROUP')
LARGE_NUMBERS_GROUP_ = URIRef(NAMESPACE + 'LARGE_NUMBERS_GROUP-')
LARGE_NUMBERS_PATIENT = URIRef(NAMESPACE + 'LARGE_NUMBERS_PATIENT')
LARGE_NUMBERS_RECIPIENT = URIRef(NAMESPACE + 'LARGE_NUMBERS_RECIPIENT')
LEGALLY_IMPOSED = URIRef(NAMESPACE + 'LEGALLY_IMPOSED')
LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'LEGALLY_IMPOSED-')
LEGAL_ACTION = URIRef(NAMESPACE + 'LEGAL_ACTION')
LOSE_POSITION_EMPLOYEE_POSITION = URIRef(NAMESPACE + 'LOSE_POSITION_EMPLOYEE_POSITION')
LOSE_POSSESSION_AGENT_THEME = URIRef(NAMESPACE + 'LOSE_POSSESSION_AGENT_THEME')
LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'LOSE_POSSESSION_DONOR_PATIENT')
LOSE_POSSESSION_DONOR_PATIENT_ = URIRef(NAMESPACE + 'LOSE_POSSESSION_DONOR_PATIENT-')
LOSE_POSSESSION_RECIPIENT_ASSET = URIRef(NAMESPACE + 'LOSE_POSSESSION_RECIPIENT_ASSET')
LOSE_POWER_OVER_EMPLOYER_EMPLOYEE = URIRef(NAMESPACE + 'LOSE_POWER_OVER_EMPLOYER_EMPLOYEE')
LeadAccompanyChaseFollow = URIRef(NAMESPACE + 'LeadAccompanyChaseFollow')
LeadAccompanyChaseFollow_CHANGES_LOCATION_COTHEME = URIRef(NAMESPACE + 'LeadAccompanyChaseFollow-CHANGES_LOCATION_COTHEME')
LeadAccompanyChaseFollow_COTHEME = URIRef(NAMESPACE + 'LeadAccompanyChaseFollow-COTHEME')
LeadAccompanyChaseFollow_SELF_MOTION_COTHEME = URIRef(NAMESPACE + 'LeadAccompanyChaseFollow-SELF_MOTION_COTHEME')
LeadAccompanyChaseFollow_SELF_MOTION_THEME = URIRef(NAMESPACE + 'LeadAccompanyChaseFollow-SELF_MOTION_THEME')
LeadAccompanyChaseFollow_THEME = URIRef(NAMESPACE + 'LeadAccompanyChaseFollow-THEME')
Legalize = URIRef(NAMESPACE + 'Legalize')
Legalize_AGENT = URIRef(NAMESPACE + 'Legalize-AGENT')
Legalize_BENEFICIARY = URIRef(NAMESPACE + 'Legalize-BENEFICIARY')
Legalize_IS_CRIME_OR_CRIMINAL_PATIENT_ = URIRef(NAMESPACE + 'Legalize-IS_CRIME_OR_CRIMINAL_PATIENT-')
Legalize_PATIENT = URIRef(NAMESPACE + 'Legalize-PATIENT')
Legislate = URIRef(NAMESPACE + 'Legislate')
Legislate_ADJUDICATE = URIRef(NAMESPACE + 'Legislate-ADJUDICATE')
Legislate_ADJUDICATOR = URIRef(NAMESPACE + 'Legislate-ADJUDICATOR')
Legislate_CREATED_TOPIC = URIRef(NAMESPACE + 'Legislate-CREATED_TOPIC')
Legislate_ENACT_ADJUDICATOR_TOPIC = URIRef(NAMESPACE + 'Legislate-ENACT_ADJUDICATOR_TOPIC')
Legislate_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Legislate-LEGALLY_IMPOSED')
Legislate_PUBLIC_VOTE_ = URIRef(NAMESPACE + 'Legislate-PUBLIC_VOTE-')
Legislate_REPRESENT_ORG_GPE_AGENT = URIRef(NAMESPACE + 'Legislate-REPRESENT_ORG_GPE_AGENT')
Legislate_RESULT = URIRef(NAMESPACE + 'Legislate-RESULT')
Legislate_TOPIC = URIRef(NAMESPACE + 'Legislate-TOPIC')
LegislationAndContracts = URIRef(NAMESPACE + 'LegislationAndContracts')
LegislationAndContracts_ADJUDICATOR = URIRef(NAMESPACE + 'LegislationAndContracts-ADJUDICATOR')
LegislationAndContracts_RECIPIENT = URIRef(NAMESPACE + 'LegislationAndContracts-RECIPIENT')
LegislationAndContracts_RESULT = URIRef(NAMESPACE + 'LegislationAndContracts-RESULT')
LegislationAndContracts_TOPIC = URIRef(NAMESPACE + 'LegislationAndContracts-TOPIC')
Lose_Election = URIRef(NAMESPACE + 'Lose_Election')
Lose_Election_CANDIDATE = URIRef(NAMESPACE + 'Lose_Election-CANDIDATE')
Lose_Election_EXPRESS_FAVOR_FOR_VOTER_CANDIDATE_ = URIRef(NAMESPACE + 'Lose_Election-EXPRESS_FAVOR_FOR_VOTER_CANDIDATE-')
Lose_Election_GAIN_POSITION_CANDIDATE_POSITION_ = URIRef(NAMESPACE + 'Lose_Election-GAIN_POSITION_CANDIDATE_POSITION-')
Lose_Election_GAIN_POWER_OVER_CANDIDATE_VOTER_ = URIRef(NAMESPACE + 'Lose_Election-GAIN_POWER_OVER_CANDIDATE_VOTER-')
Lose_Election_POSITION = URIRef(NAMESPACE + 'Lose_Election-POSITION')
Lose_Election_PUBLIC_VOTE = URIRef(NAMESPACE + 'Lose_Election-PUBLIC_VOTE')
Lose_Election_REPRESENT_ORG_GPE_CANDIDATE = URIRef(NAMESPACE + 'Lose_Election-REPRESENT_ORG_GPE_CANDIDATE')
Lose_Election_RESULT = URIRef(NAMESPACE + 'Lose_Election-RESULT')
Lose_Election_VOTER = URIRef(NAMESPACE + 'Lose_Election-VOTER')
Lose_income = URIRef(NAMESPACE + 'Lose_income')
Lose_income_DONOR = URIRef(NAMESPACE + 'Lose_income-DONOR')
Lose_income_LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'Lose_income-LOSE_POSSESSION_DONOR_PATIENT')
Lose_income_PATIENT = URIRef(NAMESPACE + 'Lose_income-PATIENT')
MAKE_CONTRACT_ADJUDICATOR_RECIPIENT = URIRef(NAMESPACE + 'MAKE_CONTRACT_ADJUDICATOR_RECIPIENT')
MAKE_CONTRACT_ADJUDICATOR_RECIPIENT_ = URIRef(NAMESPACE + 'MAKE_CONTRACT_ADJUDICATOR_RECIPIENT-')
MARRIED_AT_END_PATIENT = URIRef(NAMESPACE + 'MARRIED_AT_END_PATIENT')
MARRIED_AT_END_PATIENT_ = URIRef(NAMESPACE + 'MARRIED_AT_END_PATIENT-')
MARRIED_AT_E_TOPIC = URIRef(NAMESPACE + 'MARRIED_AT_E_TOPIC')
MARRIED_AT_START_PATIENT = URIRef(NAMESPACE + 'MARRIED_AT_START_PATIENT')
MARRIED_AT_START_PATIENT_ = URIRef(NAMESPACE + 'MARRIED_AT_START_PATIENT-')
MARRIED_AT_START_TOPIC_ = URIRef(NAMESPACE + 'MARRIED_AT_START_TOPIC-')
MEDIUM_IS_INTERNET_ = URIRef(NAMESPACE + 'MEDIUM_IS_INTERNET-')
MODE_OF_COMMUNICATION_NONVERBAL_GESTURAL = URIRef(NAMESPACE + 'MODE_OF_COMMUNICATION_NONVERBAL_GESTURAL')
MODE_OF_COMMUNICATION_TEXTUAL = URIRef(NAMESPACE + 'MODE_OF_COMMUNICATION_TEXTUAL')
MODE_OF_COMMUNICATION_TEXTUAL_ = URIRef(NAMESPACE + 'MODE_OF_COMMUNICATION_TEXTUAL-')
MODE_OF_COMMUNICATION_VERBAL = URIRef(NAMESPACE + 'MODE_OF_COMMUNICATION_VERBAL')
MODE_OF_COMMUNICATION_VERBAL_ = URIRef(NAMESPACE + 'MODE_OF_COMMUNICATION_VERBAL-')
MOTION_IS_HORIZONAL = URIRef(NAMESPACE + 'MOTION_IS_HORIZONAL')
MOTION_IS_HORIZONAL_ = URIRef(NAMESPACE + 'MOTION_IS_HORIZONAL-')
MakeUndoEvent = URIRef(NAMESPACE + 'MakeUndoEvent')
MarchProtestPoliticalGathering = URIRef(NAMESPACE + 'MarchProtestPoliticalGathering')
MarchProtestPoliticalGathering_AGENT = URIRef(NAMESPACE + 'MarchProtestPoliticalGathering-AGENT')
MarchProtestPoliticalGathering_DESTINATION = URIRef(NAMESPACE + 'MarchProtestPoliticalGathering-DESTINATION')
MarchProtestPoliticalGathering_DISPERSED_AGENT_ = URIRef(NAMESPACE + 'MarchProtestPoliticalGathering-DISPERSED_AGENT-')
MarchProtestPoliticalGathering_LARGE_NUMBERS_AGENT = URIRef(NAMESPACE + 'MarchProtestPoliticalGathering-LARGE_NUMBERS_AGENT')
MarchProtestPoliticalGathering_PATIENT = URIRef(NAMESPACE + 'MarchProtestPoliticalGathering-PATIENT')
MarchProtestPoliticalGathering_TOPIC = URIRef(NAMESPACE + 'MarchProtestPoliticalGathering-TOPIC')
Marry = URIRef(NAMESPACE + 'Marry')
Marry_ACT_AS_LEGAL_AUTHORITY_AGENT = URIRef(NAMESPACE + 'Marry-ACT_AS_LEGAL_AUTHORITY_AGENT')
Marry_AGENT = URIRef(NAMESPACE + 'Marry-AGENT')
Marry_BUSINESS_ = URIRef(NAMESPACE + 'Marry-BUSINESS-')
Marry_FAMILY_MARITAL = URIRef(NAMESPACE + 'Marry-FAMILY_MARITAL')
Marry_MARRIED_AT_END_PATIENT = URIRef(NAMESPACE + 'Marry-MARRIED_AT_END_PATIENT')
Marry_MARRIED_AT_START_PATIENT_ = URIRef(NAMESPACE + 'Marry-MARRIED_AT_START_PATIENT-')
Marry_PATIENT = URIRef(NAMESPACE + 'Marry-PATIENT')
Marry_PERSONAL_LIFE_EVENT_PATIENT = URIRef(NAMESPACE + 'Marry-PERSONAL_LIFE_EVENT_PATIENT')
Marry_VOLITIONAL_AGENT = URIRef(NAMESPACE + 'Marry-VOLITIONAL_AGENT')
Marry_VOLITIONAL_PATIENT = URIRef(NAMESPACE + 'Marry-VOLITIONAL_PATIENT')
MassacreGenocide = URIRef(NAMESPACE + 'MassacreGenocide')
MassacreGenocide_AGENT = URIRef(NAMESPACE + 'MassacreGenocide-AGENT')
MassacreGenocide_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'MassacreGenocide-ATTEMPT_HARM_AGENT_PATIENT')
MassacreGenocide_DESTROYED_PATIENT = URIRef(NAMESPACE + 'MassacreGenocide-DESTROYED_PATIENT')
MassacreGenocide_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'MassacreGenocide-ENTROPY_INCREASE_PATIENT')
MassacreGenocide_LARGE_NUMBERS_PATIENT = URIRef(NAMESPACE + 'MassacreGenocide-LARGE_NUMBERS_PATIENT')
MassacreGenocide_PATIENT = URIRef(NAMESPACE + 'MassacreGenocide-PATIENT')
MassacreGenocide_PHYSICALACTION = URIRef(NAMESPACE + 'MassacreGenocide-PHYSICALACTION')
MassacreGenocide_POLITICAL_ = URIRef(NAMESPACE + 'MassacreGenocide-POLITICAL-')
MassacreGenocide_VIOLENT = URIRef(NAMESPACE + 'MassacreGenocide-VIOLENT')
MassacreGenocide_VOLITIONAL_AGENT = URIRef(NAMESPACE + 'MassacreGenocide-VOLITIONAL_AGENT')
MediaStatement = URIRef(NAMESPACE + 'MediaStatement')
MediaStatement_AGENT = URIRef(NAMESPACE + 'MediaStatement-AGENT')
MediaStatement_BELIEVE_TO_BE_TRUE_AGENT_TOPIC = URIRef(NAMESPACE + 'MediaStatement-BELIEVE_TO_BE_TRUE_AGENT_TOPIC')
MediaStatement_COLOCATED_AGENT_RECIPIENT_ = URIRef(NAMESPACE + 'MediaStatement-COLOCATED_AGENT_RECIPIENT-')
MediaStatement_COMM_METHOD = URIRef(NAMESPACE + 'MediaStatement-COMM_METHOD')
MediaStatement_COMM_ONEWAY = URIRef(NAMESPACE + 'MediaStatement-COMM-ONEWAY')
MediaStatement_INSTR = URIRef(NAMESPACE + 'MediaStatement-INSTR')
MediaStatement_LARGE_NUMBERS_RECIPIENT = URIRef(NAMESPACE + 'MediaStatement-LARGE_NUMBERS_RECIPIENT')
MediaStatement_RECIPIENT = URIRef(NAMESPACE + 'MediaStatement-RECIPIENT')
MediaStatement_SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'MediaStatement-SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC')
MediaStatement_TOPIC = URIRef(NAMESPACE + 'MediaStatement-TOPIC')
Meet = URIRef(NAMESPACE + 'Meet')
Meet_GROUP = URIRef(NAMESPACE + 'Meet-GROUP')
Meet_INSTIGATES_TOPIC = URIRef(NAMESPACE + 'Meet-INSTIGATES_TOPIC')
Meet_LARGE_NUMBERS_GROUP_ = URIRef(NAMESPACE + 'Meet-LARGE_NUMBERS_GROUP-')
Meet_MODE_OF_COMMUNICATION_TEXTUAL_ = URIRef(NAMESPACE + 'Meet-MODE_OF_COMMUNICATION_TEXTUAL-')
Meet_MODE_OF_COMMUNICATION_VERBAL = URIRef(NAMESPACE + 'Meet-MODE_OF_COMMUNICATION_VERBAL')
Meet_TOPIC = URIRef(NAMESPACE + 'Meet-TOPIC')
MentalEvent = URIRef(NAMESPACE + 'MentalEvent')
MergeOrg = URIRef(NAMESPACE + 'MergeOrg')
MergeOrg_AGENT = URIRef(NAMESPACE + 'MergeOrg-AGENT')
MergeOrg_BUSINESS = URIRef(NAMESPACE + 'MergeOrg-BUSINESS')
MergeOrg_CREATED_RESULT = URIRef(NAMESPACE + 'MergeOrg-CREATED_RESULT')
MergeOrg_DESTROYED_PATIENT = URIRef(NAMESPACE + 'MergeOrg-DESTROYED_PATIENT')
MergeOrg_FAMILY_MARITAL_ = URIRef(NAMESPACE + 'MergeOrg-FAMILY_MARITAL-')
MergeOrg_INSTIGATES_AGENT = URIRef(NAMESPACE + 'MergeOrg-INSTIGATES_AGENT')
MergeOrg_PATIENT = URIRef(NAMESPACE + 'MergeOrg-PATIENT')
MergeOrg_RESULT = URIRef(NAMESPACE + 'MergeOrg-RESULT')
Movement = URIRef(NAMESPACE + 'Movement')
MovementEvent = URIRef(NAMESPACE + 'MovementEvent')
Movement_AGENT = URIRef(NAMESPACE + 'Movement-AGENT')
Movement_CHANGES_LOCATION_THEME = URIRef(NAMESPACE + 'Movement-CHANGES_LOCATION_THEME')
Movement_COTHEME = URIRef(NAMESPACE + 'Movement-COTHEME')
Movement_DESTINATION = URIRef(NAMESPACE + 'Movement-DESTINATION')
Movement_INITIAL_LOCATION = URIRef(NAMESPACE + 'Movement-INITIAL_LOCATION')
Movement_INSTR = URIRef(NAMESPACE + 'Movement-INSTR')
Movement_RECIPIENT = URIRef(NAMESPACE + 'Movement-RECIPIENT')
Movement_THEME = URIRef(NAMESPACE + 'Movement-THEME')
NATURAL_PROCESS = URIRef(NAMESPACE + 'NATURAL_PROCESS')
NATURAL_PROCESS_ = URIRef(NAMESPACE + 'NATURAL_PROCESS-')
Nominate = URIRef(NAMESPACE + 'Nominate')
Nominate_AGENT = URIRef(NAMESPACE + 'Nominate-AGENT')
Nominate_CANDIDATE = URIRef(NAMESPACE + 'Nominate-CANDIDATE')
Nominate_POSITION = URIRef(NAMESPACE + 'Nominate-POSITION')
Nominate_REPRESENT_ORG_GPE_CANDIDATE = URIRef(NAMESPACE + 'Nominate-REPRESENT_ORG_GPE_CANDIDATE')
Nominate_RESULT = URIRef(NAMESPACE + 'Nominate-RESULT')
Nominate_VOTER = URIRef(NAMESPACE + 'Nominate-VOTER')
NonPhysicalConflict = URIRef(NAMESPACE + 'NonPhysicalConflict')
NonPhysicalConflict_AGENT = URIRef(NAMESPACE + 'NonPhysicalConflict-AGENT')
NonPhysicalConflict_INSTR = URIRef(NAMESPACE + 'NonPhysicalConflict-INSTR')
NonPhysicalConflict_PATIENT = URIRef(NAMESPACE + 'NonPhysicalConflict-PATIENT')
NonPhysicalConflict_PHYSICALACTION_ = URIRef(NAMESPACE + 'NonPhysicalConflict-PHYSICALACTION-')
NonPhysicalConflict_VIOLENT_ = URIRef(NAMESPACE + 'NonPhysicalConflict-VIOLENT-')
Nonlegal_agreement = URIRef(NAMESPACE + 'Nonlegal_agreement')
Nonlegal_agreement_ADJUDICATOR = URIRef(NAMESPACE + 'Nonlegal_agreement-ADJUDICATOR')
Nonlegal_agreement_AGREE_TO_ADJUDICATOR_TOPIC = URIRef(NAMESPACE + 'Nonlegal_agreement-AGREE_TO_ADJUDICATOR_TOPIC')
Nonlegal_agreement_AGREE_TO_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'Nonlegal_agreement-AGREE_TO_RECIPIENT_TOPIC')
Nonlegal_agreement_CREATED_TOPIC = URIRef(NAMESPACE + 'Nonlegal_agreement-CREATED_TOPIC')
Nonlegal_agreement_ENACT_ADJUDICATOR_TOPIC = URIRef(NAMESPACE + 'Nonlegal_agreement-ENACT_ADJUDICATOR_TOPIC')
Nonlegal_agreement_LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'Nonlegal_agreement-LEGALLY_IMPOSED-')
Nonlegal_agreement_MAKE_CONTRACT_ADJUDICATOR_RECIPIENT = URIRef(NAMESPACE + 'Nonlegal_agreement-MAKE_CONTRACT_ADJUDICATOR_RECIPIENT')
Nonlegal_agreement_PUBLIC_VOTE_ = URIRef(NAMESPACE + 'Nonlegal_agreement-PUBLIC_VOTE-')
Nonlegal_agreement_RECIPIENT = URIRef(NAMESPACE + 'Nonlegal_agreement-RECIPIENT')
Nonlegal_agreement_TOPIC = URIRef(NAMESPACE + 'Nonlegal_agreement-TOPIC')
NonpoliticalGathering = URIRef(NAMESPACE + 'NonpoliticalGathering')
NonpoliticalGathering_CULTURAL_RELIGIOUS = URIRef(NAMESPACE + 'NonpoliticalGathering-CULTURAL_RELIGIOUS')
NonpoliticalGathering_GROUP = URIRef(NAMESPACE + 'NonpoliticalGathering-GROUP')
NonpoliticalGathering_INSTIGATES_TOPIC = URIRef(NAMESPACE + 'NonpoliticalGathering-INSTIGATES_TOPIC')
NonpoliticalGathering_LARGE_NUMBERS_GROUP = URIRef(NAMESPACE + 'NonpoliticalGathering-LARGE_NUMBERS_GROUP')
NonpoliticalGathering_MODE_OF_COMMUNICATION_TEXTUAL_ = URIRef(NAMESPACE + 'NonpoliticalGathering-MODE_OF_COMMUNICATION_TEXTUAL-')
NonpoliticalGathering_MODE_OF_COMMUNICATION_VERBAL = URIRef(NAMESPACE + 'NonpoliticalGathering-MODE_OF_COMMUNICATION_VERBAL')
NonpoliticalGathering_POLITICAL_ = URIRef(NAMESPACE + 'NonpoliticalGathering-POLITICAL-')
NonpoliticalGathering_TOPIC = URIRef(NAMESPACE + 'NonpoliticalGathering-TOPIC')
Nonverbal_Communication = URIRef(NAMESPACE + 'Nonverbal_Communication')
Nonverbal_Communication_AGENT = URIRef(NAMESPACE + 'Nonverbal_Communication-AGENT')
Nonverbal_Communication_COLOCATED_AGENT_RECIPIENT = URIRef(NAMESPACE + 'Nonverbal_Communication-COLOCATED_AGENT_RECIPIENT')
Nonverbal_Communication_COMM_METHOD_ = URIRef(NAMESPACE + 'Nonverbal_Communication-COMM_METHOD-')
Nonverbal_Communication_COMM_ONEWAY_ = URIRef(NAMESPACE + 'Nonverbal_Communication-COMM-ONEWAY-')
Nonverbal_Communication_MODE_OF_COMMUNICATION_NONVERBAL_GESTURAL = URIRef(NAMESPACE + 'Nonverbal_Communication-MODE_OF_COMMUNICATION_NONVERBAL_GESTURAL')
Nonverbal_Communication_MODE_OF_COMMUNICATION_TEXTUAL_ = URIRef(NAMESPACE + 'Nonverbal_Communication-MODE_OF_COMMUNICATION_TEXTUAL-')
Nonverbal_Communication_MODE_OF_COMMUNICATION_VERBAL_ = URIRef(NAMESPACE + 'Nonverbal_Communication-MODE_OF_COMMUNICATION_VERBAL-')
Nonverbal_Communication_RECIPIENT = URIRef(NAMESPACE + 'Nonverbal_Communication-RECIPIENT')
Nonverbal_Communication_TOPIC = URIRef(NAMESPACE + 'Nonverbal_Communication-TOPIC')
NonviolentDeath = URIRef(NAMESPACE + 'NonviolentDeath')
NonviolentDeath_CHANGES_STATE_PATIENT = URIRef(NAMESPACE + 'NonviolentDeath-CHANGES_STATE_PATIENT')
NonviolentDeath_DESTROYED_PATIENT = URIRef(NAMESPACE + 'NonviolentDeath-DESTROYED_PATIENT')
NonviolentDeath_PATIENT = URIRef(NAMESPACE + 'NonviolentDeath-PATIENT')
NonviolentDeath_PERSONAL_LIFE_EVENT_PATIENT = URIRef(NAMESPACE + 'NonviolentDeath-PERSONAL_LIFE_EVENT_PATIENT')
NonviolentDeath_VIOLENT_ = URIRef(NAMESPACE + 'NonviolentDeath-VIOLENT-')
Nonviolent_ThrowLaunch = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch')
Nonviolent_ThrowLaunch_AGENT = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-AGENT')
Nonviolent_ThrowLaunch_CHANGES_LOCATION_AGENT_ = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-CHANGES_LOCATION_AGENT-')
Nonviolent_ThrowLaunch_DESTINATION = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-DESTINATION')
Nonviolent_ThrowLaunch_INITIAL_LOCATION = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-INITIAL_LOCATION')
Nonviolent_ThrowLaunch_LOSE_POSSESSION_AGENT_THEME = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-LOSE_POSSESSION_AGENT_THEME')
Nonviolent_ThrowLaunch_PROJECTILE_MANNER = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-PROJECTILE_MANNER')
Nonviolent_ThrowLaunch_SELF_MOTION_THEME_ = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-SELF_MOTION_THEME-')
Nonviolent_ThrowLaunch_START_AT_LOCATION_AGENT_INITIAL_LOCATION = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-START_AT_LOCATION_AGENT_INITIAL_LOCATION')
Nonviolent_ThrowLaunch_START_AT_LOCATION_THEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-START_AT_LOCATION_THEME_INITIAL_LOCATION')
Nonviolent_ThrowLaunch_THEME = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-THEME')
Nonviolent_ThrowLaunch_VIOLENT_ = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-VIOLENT-')
Nonviolent_ThrowLaunch_VOLITIONAL_AGENT = URIRef(NAMESPACE + 'Nonviolent_ThrowLaunch-VOLITIONAL_AGENT')
OCCUR_BEFORE_ADJUDICATION_ = URIRef(NAMESPACE + 'OCCUR_BEFORE_ADJUDICATION-')
ObserveUsingInstrument = URIRef(NAMESPACE + 'ObserveUsingInstrument')
ObserveUsingInstrument_AGENT = URIRef(NAMESPACE + 'ObserveUsingInstrument-AGENT')
ObserveUsingInstrument_DIRECTLY_OBSERVE_AGENT_PATIENT_ = URIRef(NAMESPACE + 'ObserveUsingInstrument-DIRECTLY_OBSERVE_AGENT_PATIENT-')
ObserveUsingInstrument_GET_INFO_AGENT_PATIENT = URIRef(NAMESPACE + 'ObserveUsingInstrument-GET_INFO_AGENT_PATIENT')
ObserveUsingInstrument_INSTR = URIRef(NAMESPACE + 'ObserveUsingInstrument-INSTR')
ObserveUsingInstrument_PATIENT = URIRef(NAMESPACE + 'ObserveUsingInstrument-PATIENT')
OrganizationRelationChangeEvents = URIRef(NAMESPACE + 'OrganizationRelationChangeEvents')
OrganizationRelationChangeEvents_AGENT = URIRef(NAMESPACE + 'OrganizationRelationChangeEvents-AGENT')
OrganizationRelationChangeEvents_PATIENT = URIRef(NAMESPACE + 'OrganizationRelationChangeEvents-PATIENT')
OrganizationRelationChangeEvents_RESULT = URIRef(NAMESPACE + 'OrganizationRelationChangeEvents-RESULT')
Outlaw = URIRef(NAMESPACE + 'Outlaw')
Outlaw_AGENT = URIRef(NAMESPACE + 'Outlaw-AGENT')
Outlaw_IS_CRIME_OR_CRIMINAL_PATIENT = URIRef(NAMESPACE + 'Outlaw-IS_CRIME_OR_CRIMINAL_PATIENT')
Outlaw_PATIENT = URIRef(NAMESPACE + 'Outlaw-PATIENT')
PATIENT = URIRef(NAMESPACE + 'PATIENT')
PAYS_FOR_PAST_FUTURE_ACTION = URIRef(NAMESPACE + 'PAYS_FOR_PAST_FUTURE_ACTION')
PERSONAL_LIFE_EVENT_PATIENT = URIRef(NAMESPACE + 'PERSONAL_LIFE_EVENT_PATIENT')
PHYSICALACTION = URIRef(NAMESPACE + 'PHYSICALACTION')
PHYSICALACTION_ = URIRef(NAMESPACE + 'PHYSICALACTION-')
PLACE = URIRef(NAMESPACE + 'PLACE')
POLITICAL = URIRef(NAMESPACE + 'POLITICAL')
POLITICAL_ = URIRef(NAMESPACE + 'POLITICAL-')
POSITION = URIRef(NAMESPACE + 'POSITION')
PROJECTILE_MANNER = URIRef(NAMESPACE + 'PROJECTILE_MANNER')
PROJECTILE_MANNER_ = URIRef(NAMESPACE + 'PROJECTILE_MANNER-')
PROSECUTOR = URIRef(NAMESPACE + 'PROSECUTOR')
PUBLIC_VOTE = URIRef(NAMESPACE + 'PUBLIC_VOTE')
PUBLIC_VOTE_ = URIRef(NAMESPACE + 'PUBLIC_VOTE-')
PUNISHMENT_FOR_CRIME = URIRef(NAMESPACE + 'PUNISHMENT_FOR_CRIME')
Pardon = URIRef(NAMESPACE + 'Pardon')
Pardon_ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR = URIRef(NAMESPACE + 'Pardon-ACT_AS_LEGAL_AUTHORITY_ADJUDICATOR')
Pardon_ADJUDICATOR = URIRef(NAMESPACE + 'Pardon-ADJUDICATOR')
Pardon_AFTER_TRIAL_HEARING = URIRef(NAMESPACE + 'Pardon-AFTER_TRIAL_HEARING')
Pardon_BEFORE_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Pardon-BEFORE_TRIAL_HEARING-')
Pardon_COLOCATED_ADJUDICATOR_DEFENDENT = URIRef(NAMESPACE + 'Pardon-COLOCATED_ADJUDICATOR_DEFENDENT')
Pardon_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Pardon-CRIME_OR_CAUSE')
Pardon_DECIDED_BY_ADJUDICATOR = URIRef(NAMESPACE + 'Pardon-DECIDED_BY_ADJUDICATOR')
Pardon_DEFENDANT = URIRef(NAMESPACE + 'Pardon-DEFENDANT')
Pardon_DURING_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Pardon-DURING_TRIAL_HEARING-')
Pardon_ENTAIL_FUTURE_LEGAL_PUNISHMENT_ = URIRef(NAMESPACE + 'Pardon-ENTAIL_FUTURE_LEGAL_PUNISHMENT-')
Pardon_LEGAL_ACTION = URIRef(NAMESPACE + 'Pardon-LEGAL_ACTION')
Pardon_SENTENCE = URIRef(NAMESPACE + 'Pardon-SENTENCE')
PayForService = URIRef(NAMESPACE + 'PayForService')
PayForService_CAUSED_BY_POSSIBLE_OR_PAST_EVENT = URIRef(NAMESPACE + 'PayForService-CAUSED_BY_POSSIBLE_OR_PAST_EVENT')
PayForService_DONOR = URIRef(NAMESPACE + 'PayForService-DONOR')
PayForService_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'PayForService-GAIN_POSSESSION_RECIPIENT_PATIENT')
PayForService_IS_CRIME_OR_CRIMINAL_ = URIRef(NAMESPACE + 'PayForService-IS_CRIME_OR_CRIMINAL-')
PayForService_LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'PayForService-LOSE_POSSESSION_DONOR_PATIENT')
PayForService_PATIENT = URIRef(NAMESPACE + 'PayForService-PATIENT')
PayForService_PAYS_FOR_PAST_FUTURE_ACTION = URIRef(NAMESPACE + 'PayForService-PAYS_FOR_PAST_FUTURE_ACTION')
PayForService_RECIPIENT = URIRef(NAMESPACE + 'PayForService-RECIPIENT')
Pay_TaxesDuesFines = URIRef(NAMESPACE + 'Pay_TaxesDuesFines')
Pay_TaxesDuesFines_DONOR = URIRef(NAMESPACE + 'Pay_TaxesDuesFines-DONOR')
Pay_TaxesDuesFines_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'Pay_TaxesDuesFines-GAIN_POSSESSION_RECIPIENT_PATIENT')
Pay_TaxesDuesFines_IS_CRIME_OR_CRIMINAL_ = URIRef(NAMESPACE + 'Pay_TaxesDuesFines-IS_CRIME_OR_CRIMINAL-')
Pay_TaxesDuesFines_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Pay_TaxesDuesFines-LEGALLY_IMPOSED')
Pay_TaxesDuesFines_LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'Pay_TaxesDuesFines-LOSE_POSSESSION_DONOR_PATIENT')
Pay_TaxesDuesFines_PATIENT = URIRef(NAMESPACE + 'Pay_TaxesDuesFines-PATIENT')
Pay_TaxesDuesFines_RECIPIENT = URIRef(NAMESPACE + 'Pay_TaxesDuesFines-RECIPIENT')
PhysicalConflict = URIRef(NAMESPACE + 'PhysicalConflict')
PhysicalConflict_AGENT = URIRef(NAMESPACE + 'PhysicalConflict-AGENT')
PhysicalConflict_INSTR = URIRef(NAMESPACE + 'PhysicalConflict-INSTR')
PhysicalConflict_PATIENT = URIRef(NAMESPACE + 'PhysicalConflict-PATIENT')
PhysicalInvestigateInspect = URIRef(NAMESPACE + 'PhysicalInvestigateInspect')
PhysicalInvestigateInspect_AGENT = URIRef(NAMESPACE + 'PhysicalInvestigateInspect-AGENT')
PhysicalInvestigateInspect_COLOCATED_AGENT_PATIENT = URIRef(NAMESPACE + 'PhysicalInvestigateInspect-COLOCATED_AGENT_PATIENT')
PhysicalInvestigateInspect_GET_INFO_AGENT_PATIENT = URIRef(NAMESPACE + 'PhysicalInvestigateInspect-GET_INFO_AGENT_PATIENT')
PhysicalInvestigateInspect_PATIENT = URIRef(NAMESPACE + 'PhysicalInvestigateInspect-PATIENT')
PoliticalConflict = URIRef(NAMESPACE + 'PoliticalConflict')
PoliticalConflict_AGENT = URIRef(NAMESPACE + 'PoliticalConflict-AGENT')
PoliticalConflict_DESTINATION = URIRef(NAMESPACE + 'PoliticalConflict-DESTINATION')
PoliticalConflict_INSTR = URIRef(NAMESPACE + 'PoliticalConflict-INSTR')
PoliticalConflict_PATIENT = URIRef(NAMESPACE + 'PoliticalConflict-PATIENT')
PoliticalConflict_POLITICAL = URIRef(NAMESPACE + 'PoliticalConflict-POLITICAL')
PoliticalConflict_TOPIC = URIRef(NAMESPACE + 'PoliticalConflict-TOPIC')
Prevarication = URIRef(NAMESPACE + 'Prevarication')
Prevarication_AGENT = URIRef(NAMESPACE + 'Prevarication-AGENT')
Prevarication_BELIEVE_TO_BE_TRUE_AGENT_TOPIC_ = URIRef(NAMESPACE + 'Prevarication-BELIEVE_TO_BE_TRUE_AGENT_TOPIC-')
Prevarication_COMM_ONEWAY = URIRef(NAMESPACE + 'Prevarication-COMM-ONEWAY')
Prevarication_RECIPIENT = URIRef(NAMESPACE + 'Prevarication-RECIPIENT')
Prevarication_SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'Prevarication-SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC')
Prevarication_TOPIC = URIRef(NAMESPACE + 'Prevarication-TOPIC')
PreventEntry = URIRef(NAMESPACE + 'PreventEntry')
PreventEntry_AGENT = URIRef(NAMESPACE + 'PreventEntry-AGENT')
PreventEntry_ALLOWED_ENTRY_BENEFICIARY_ = URIRef(NAMESPACE + 'PreventEntry-ALLOWED_ENTRY_BENEFICIARY-')
PreventEntry_BENEFICIARY = URIRef(NAMESPACE + 'PreventEntry-BENEFICIARY')
Prevent_Action = URIRef(NAMESPACE + 'Prevent_Action')
Prevent_Action_AGENT = URIRef(NAMESPACE + 'Prevent_Action-AGENT')
Prevent_Action_ALLOW_ = URIRef(NAMESPACE + 'Prevent_Action-ALLOW-')
Prevent_Action_BENEFICIARY = URIRef(NAMESPACE + 'Prevent_Action-BENEFICIARY')
Prevent_Action_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'Prevent_Action-LEGALLY_IMPOSED')
Prevent_Action_PATIENT = URIRef(NAMESPACE + 'Prevent_Action-PATIENT')
Prevent_Exit = URIRef(NAMESPACE + 'Prevent_Exit')
Prevent_Exit_AGENT = URIRef(NAMESPACE + 'Prevent_Exit-AGENT')
Prevent_Exit_ALLOWED_TO_EXIT_LOCATION_PATIENT_PLACE_ = URIRef(NAMESPACE + 'Prevent_Exit-ALLOWED_TO_EXIT_LOCATION_PATIENT_PLACE-')
Prevent_Exit_ALLOW_ = URIRef(NAMESPACE + 'Prevent_Exit-ALLOW-')
Prevent_Exit_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Prevent_Exit-CRIME_OR_CAUSE')
Prevent_Exit_HAVE_PHYSICAL_CONTROL_OVER_AGENT_PATIENT = URIRef(NAMESPACE + 'Prevent_Exit-HAVE_PHYSICAL_CONTROL_OVER_AGENT_PATIENT')
Prevent_Exit_PATIENT = URIRef(NAMESPACE + 'Prevent_Exit-PATIENT')
Prevent_Exit_PLACE = URIRef(NAMESPACE + 'Prevent_Exit-PLACE')
ProcessImprove = URIRef(NAMESPACE + 'ProcessImprove')
ProcessImprove_CREATED_PATIENT_ = URIRef(NAMESPACE + 'ProcessImprove-CREATED_PATIENT-')
ProcessImprove_PATIENT = URIRef(NAMESPACE + 'ProcessImprove-PATIENT')
Promote = URIRef(NAMESPACE + 'Promote')
Promote_BUSINESS = URIRef(NAMESPACE + 'Promote-BUSINESS')
Promote_EMPLOYEE = URIRef(NAMESPACE + 'Promote-EMPLOYEE')
Promote_EMPLOYER = URIRef(NAMESPACE + 'Promote-EMPLOYER')
Promote_GAIN_POSITION_EMPLOYEE_POSITION = URIRef(NAMESPACE + 'Promote-GAIN_POSITION_EMPLOYEE_POSITION')
Promote_INITIAL_LOCATION = URIRef(NAMESPACE + 'Promote-INITIAL_LOCATION')
Promote_POSITION = URIRef(NAMESPACE + 'Promote-POSITION')
Promote_VOLITIONAL_EMPLOYEE = URIRef(NAMESPACE + 'Promote-VOLITIONAL_EMPLOYEE')
Promote_VOLITIONAL_EMPLOYER = URIRef(NAMESPACE + 'Promote-VOLITIONAL_EMPLOYER')
PublicStatementInPerson = URIRef(NAMESPACE + 'PublicStatementInPerson')
PublicStatementInPerson_AGENT = URIRef(NAMESPACE + 'PublicStatementInPerson-AGENT')
PublicStatementInPerson_BELIEVE_TO_BE_TRUE_AGENT_TOPIC = URIRef(NAMESPACE + 'PublicStatementInPerson-BELIEVE_TO_BE_TRUE_AGENT_TOPIC')
PublicStatementInPerson_COLOCATED_AGENT_RECIPIENT = URIRef(NAMESPACE + 'PublicStatementInPerson-COLOCATED_AGENT_RECIPIENT')
PublicStatementInPerson_COMM_METHOD_ = URIRef(NAMESPACE + 'PublicStatementInPerson-COMM_METHOD-')
PublicStatementInPerson_COMM_ONEWAY = URIRef(NAMESPACE + 'PublicStatementInPerson-COMM-ONEWAY')
PublicStatementInPerson_MEDIUM_IS_INTERNET_ = URIRef(NAMESPACE + 'PublicStatementInPerson-MEDIUM_IS_INTERNET-')
PublicStatementInPerson_MODE_OF_COMMUNICATION_TEXTUAL_ = URIRef(NAMESPACE + 'PublicStatementInPerson-MODE_OF_COMMUNICATION_TEXTUAL-')
PublicStatementInPerson_MODE_OF_COMMUNICATION_VERBAL = URIRef(NAMESPACE + 'PublicStatementInPerson-MODE_OF_COMMUNICATION_VERBAL')
PublicStatementInPerson_RECIPIENT = URIRef(NAMESPACE + 'PublicStatementInPerson-RECIPIENT')
PublicStatementInPerson_SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'PublicStatementInPerson-SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC')
PublicStatementInPerson_TOPIC = URIRef(NAMESPACE + 'PublicStatementInPerson-TOPIC')
PublicVotingEvent = URIRef(NAMESPACE + 'PublicVotingEvent')
PublicVotingEvent_AGENT = URIRef(NAMESPACE + 'PublicVotingEvent-AGENT')
PublicVotingEvent_BE_IN_RACE_FOR_CANDIDATE_POSITION = URIRef(NAMESPACE + 'PublicVotingEvent-BE_IN_RACE_FOR_CANDIDATE_POSITION')
PublicVotingEvent_CANDIDATE = URIRef(NAMESPACE + 'PublicVotingEvent-CANDIDATE')
PublicVotingEvent_POSITION = URIRef(NAMESPACE + 'PublicVotingEvent-POSITION')
PublicVotingEvent_RESULT = URIRef(NAMESPACE + 'PublicVotingEvent-RESULT')
PublicVotingEvent_VOTER = URIRef(NAMESPACE + 'PublicVotingEvent-VOTER')
Purchase = URIRef(NAMESPACE + 'Purchase')
Purchase_ASSET = URIRef(NAMESPACE + 'Purchase-ASSET')
Purchase_DONOR = URIRef(NAMESPACE + 'Purchase-DONOR')
Purchase_GAIN_POSSESSION_DONOR_ASSET = URIRef(NAMESPACE + 'Purchase-GAIN_POSSESSION_DONOR_ASSET')
Purchase_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'Purchase-GAIN_POSSESSION_RECIPIENT_PATIENT')
Purchase_LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'Purchase-LEGALLY_IMPOSED-')
Purchase_LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'Purchase-LOSE_POSSESSION_DONOR_PATIENT')
Purchase_LOSE_POSSESSION_RECIPIENT_ASSET = URIRef(NAMESPACE + 'Purchase-LOSE_POSSESSION_RECIPIENT_ASSET')
Purchase_PATIENT = URIRef(NAMESPACE + 'Purchase-PATIENT')
Purchase_RECIPIENT = URIRef(NAMESPACE + 'Purchase-RECIPIENT')
QuestionInterrogate = URIRef(NAMESPACE + 'QuestionInterrogate')
QuestionInterrogate_AGENT = URIRef(NAMESPACE + 'QuestionInterrogate-AGENT')
QuestionInterrogate_COMMUNICATE_TO_RECIPIENT_AGENT = URIRef(NAMESPACE + 'QuestionInterrogate-COMMUNICATE_TO_RECIPIENT_AGENT')
QuestionInterrogate_COMM_ONEWAY_ = URIRef(NAMESPACE + 'QuestionInterrogate-COMM-ONEWAY-')
QuestionInterrogate_RECIPIENT = URIRef(NAMESPACE + 'QuestionInterrogate-RECIPIENT')
QuestionInterrogate_REQUEST_INFORMATION_FROM_AGENT_RECIPIENT = URIRef(NAMESPACE + 'QuestionInterrogate-REQUEST_INFORMATION_FROM_AGENT_RECIPIENT')
QuestionInterrogate_TOPIC = URIRef(NAMESPACE + 'QuestionInterrogate-TOPIC')
QuitRetire = URIRef(NAMESPACE + 'QuitRetire')
QuitRetire_BUSINESS = URIRef(NAMESPACE + 'QuitRetire-BUSINESS')
QuitRetire_EMPLOYEE = URIRef(NAMESPACE + 'QuitRetire-EMPLOYEE')
QuitRetire_EMPLOYER = URIRef(NAMESPACE + 'QuitRetire-EMPLOYER')
QuitRetire_LOSE_POSITION_EMPLOYEE_POSITION = URIRef(NAMESPACE + 'QuitRetire-LOSE_POSITION_EMPLOYEE_POSITION')
QuitRetire_LOSE_POWER_OVER_EMPLOYER_EMPLOYEE = URIRef(NAMESPACE + 'QuitRetire-LOSE_POWER_OVER_EMPLOYER_EMPLOYEE')
QuitRetire_POSITION = URIRef(NAMESPACE + 'QuitRetire-POSITION')
QuitRetire_VOLITIONAL_EMPLOYEE = URIRef(NAMESPACE + 'QuitRetire-VOLITIONAL_EMPLOYEE')
RECIPIENT = URIRef(NAMESPACE + 'RECIPIENT')
REJECT_LEADERSHIP = URIRef(NAMESPACE + 'REJECT_LEADERSHIP')
REPRESENT_ORG_GPE_ADJUDICATOR = URIRef(NAMESPACE + 'REPRESENT_ORG_GPE_ADJUDICATOR')
REPRESENT_ORG_GPE_AGENT = URIRef(NAMESPACE + 'REPRESENT_ORG_GPE_AGENT')
REPRESENT_ORG_GPE_CANDIDATE = URIRef(NAMESPACE + 'REPRESENT_ORG_GPE_CANDIDATE')
REPRESENT_ORG_GPE_PROSECUTOR = URIRef(NAMESPACE + 'REPRESENT_ORG_GPE_PROSECUTOR')
REPRESENT_ORG_GPE_RECIPIENT = URIRef(NAMESPACE + 'REPRESENT_ORG_GPE_RECIPIENT')
REQUEST_INFORMATION_FROM_AGENT_RECIPIENT = URIRef(NAMESPACE + 'REQUEST_INFORMATION_FROM_AGENT_RECIPIENT')
RESOLVE_DANGER_TO_AGENT_PATIENT = URIRef(NAMESPACE + 'RESOLVE_DANGER_TO_AGENT_PATIENT')
RESULT = URIRef(NAMESPACE + 'RESULT')
ReceiveImport = URIRef(NAMESPACE + 'ReceiveImport')
ReceiveImport_AGENT = URIRef(NAMESPACE + 'ReceiveImport-AGENT')
ReceiveImport_CHANGES_LOCATION_AGENT_ = URIRef(NAMESPACE + 'ReceiveImport-CHANGES_LOCATION_AGENT-')
ReceiveImport_CHANGES_LOCATION_RECIPIENT_ = URIRef(NAMESPACE + 'ReceiveImport-CHANGES_LOCATION_RECIPIENT-')
ReceiveImport_END_AT_LOCATION_RECIPIENT_DESTINATION = URIRef(NAMESPACE + 'ReceiveImport-END_AT_LOCATION_RECIPIENT_DESTINATION')
ReceiveImport_END_AT_LOCATION_THEME_DESTINATION = URIRef(NAMESPACE + 'ReceiveImport-END_AT_LOCATION_THEME_DESTINATION')
ReceiveImport_GAIN_POSSESSION_RECIPIENT_THEME = URIRef(NAMESPACE + 'ReceiveImport-GAIN_POSSESSION_RECIPIENT_THEME')
ReceiveImport_INITIAL_LOCATION = URIRef(NAMESPACE + 'ReceiveImport-INITIAL_LOCATION')
ReceiveImport_MOTION_IS_HORIZONAL = URIRef(NAMESPACE + 'ReceiveImport-MOTION_IS_HORIZONAL')
ReceiveImport_RECIPIENT = URIRef(NAMESPACE + 'ReceiveImport-RECIPIENT')
ReceiveImport_SELF_MOTION_THEME_ = URIRef(NAMESPACE + 'ReceiveImport-SELF_MOTION_THEME-')
ReceiveImport_START_AT_LOCATION_RECIPIENT_DESTINATION = URIRef(NAMESPACE + 'ReceiveImport-START_AT_LOCATION_RECIPIENT_DESTINATION')
ReceiveImport_START_AT_LOCATION_THEME_DESTINATION_ = URIRef(NAMESPACE + 'ReceiveImport-START_AT_LOCATION_THEME_DESTINATION-')
ReceiveImport_THEME = URIRef(NAMESPACE + 'ReceiveImport-THEME')
ReceiveImport_VOLITIONAL_RECIPIENT = URIRef(NAMESPACE + 'ReceiveImport-VOLITIONAL_RECIPIENT')
RecoverReceiveAid = URIRef(NAMESPACE + 'RecoverReceiveAid')
RecoverReceiveAid_AGENT = URIRef(NAMESPACE + 'RecoverReceiveAid-AGENT')
RecoverReceiveAid_CREATED_PATIENT_ = URIRef(NAMESPACE + 'RecoverReceiveAid-CREATED_PATIENT-')
RecoverReceiveAid_PATIENT = URIRef(NAMESPACE + 'RecoverReceiveAid-PATIENT')
RejectNullify_AgreementContractCeasefire = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire')
RejectNullify_AgreementContractCeasefire_ADJUDICATE = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-ADJUDICATE')
RejectNullify_AgreementContractCeasefire_ADJUDICATOR = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-ADJUDICATOR')
RejectNullify_AgreementContractCeasefire_AGREE_TO_ADJUDICATOR_TOPIC_ = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-AGREE_TO_ADJUDICATOR_TOPIC-')
RejectNullify_AgreementContractCeasefire_CREATED_TOPIC_ = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-CREATED_TOPIC-')
RejectNullify_AgreementContractCeasefire_ENACT_ADJUDICATOR_TOPIC_ = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-ENACT_ADJUDICATOR_TOPIC-')
RejectNullify_AgreementContractCeasefire_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-LEGALLY_IMPOSED')
RejectNullify_AgreementContractCeasefire_MAKE_CONTRACT_ADJUDICATOR_RECIPIENT_ = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-MAKE_CONTRACT_ADJUDICATOR_RECIPIENT-')
RejectNullify_AgreementContractCeasefire_PUBLIC_VOTE_ = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-PUBLIC_VOTE-')
RejectNullify_AgreementContractCeasefire_RECIPIENT = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-RECIPIENT')
RejectNullify_AgreementContractCeasefire_REPRESENT_ORG_GPE_ADJUDICATOR = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-REPRESENT_ORG_GPE_ADJUDICATOR')
RejectNullify_AgreementContractCeasefire_REPRESENT_ORG_GPE_RECIPIENT = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-REPRESENT_ORG_GPE_RECIPIENT')
RejectNullify_AgreementContractCeasefire_TOPIC = URIRef(NAMESPACE + 'RejectNullify_AgreementContractCeasefire-TOPIC')
ReleaseParole = URIRef(NAMESPACE + 'ReleaseParole')
ReleaseParole_AGENT = URIRef(NAMESPACE + 'ReleaseParole-AGENT')
ReleaseParole_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'ReleaseParole-CRIME_OR_CAUSE')
ReleaseParole_LEGALLY_IMPOSED = URIRef(NAMESPACE + 'ReleaseParole-LEGALLY_IMPOSED')
ReleaseParole_PATIENT = URIRef(NAMESPACE + 'ReleaseParole-PATIENT')
ReleaseParole_PLACE = URIRef(NAMESPACE + 'ReleaseParole-PLACE')
ReligiousTraditionalEvent = URIRef(NAMESPACE + 'ReligiousTraditionalEvent')
ReligiousTraditionalEvent_ADJUDICATOR = URIRef(NAMESPACE + 'ReligiousTraditionalEvent-ADJUDICATOR')
ReligiousTraditionalEvent_CROWD_ACTIVITY_GROUP = URIRef(NAMESPACE + 'ReligiousTraditionalEvent-CROWD_ACTIVITY_GROUP')
ReligiousTraditionalEvent_CULTURAL_RELIGIOUS = URIRef(NAMESPACE + 'ReligiousTraditionalEvent-CULTURAL_RELIGIOUS')
ReligiousTraditionalEvent_GET_INFO_GROUP_TOPIC = URIRef(NAMESPACE + 'ReligiousTraditionalEvent-GET_INFO_GROUP_TOPIC')
ReligiousTraditionalEvent_GROUP = URIRef(NAMESPACE + 'ReligiousTraditionalEvent-GROUP')
ReligiousTraditionalEvent_INSTIGATES_AGENT = URIRef(NAMESPACE + 'ReligiousTraditionalEvent-INSTIGATES_AGENT')
ReligiousTraditionalEvent_LARGE_NUMBERS_GROUP = URIRef(NAMESPACE + 'ReligiousTraditionalEvent-LARGE_NUMBERS_GROUP')
ReligiousTraditionalEvent_POLITICAL_ = URIRef(NAMESPACE + 'ReligiousTraditionalEvent-POLITICAL-')
ReligiousTraditionalEvent_TOPIC = URIRef(NAMESPACE + 'ReligiousTraditionalEvent-TOPIC')
RequestAdvise = URIRef(NAMESPACE + 'RequestAdvise')
RequestAdvise_AGENT = URIRef(NAMESPACE + 'RequestAdvise-AGENT')
RequestAdvise_COMM_ONEWAY = URIRef(NAMESPACE + 'RequestAdvise-COMM-ONEWAY')
RequestAdvise_DISCUSS_POSSIBLE_ACTION_BY_RECIPIENT = URIRef(NAMESPACE + 'RequestAdvise-DISCUSS_POSSIBLE_ACTION_BY_RECIPIENT')
RequestAdvise_HAS_INSTITUTIONAL_POWER_OVER_AT_START_AGENT_RECIPIENT_ = URIRef(NAMESPACE + 'RequestAdvise-HAS_INSTITUTIONAL_POWER_OVER_AT_START_AGENT_RECIPIENT-')
RequestAdvise_INSTR = URIRef(NAMESPACE + 'RequestAdvise-INSTR')
RequestAdvise_RECIPIENT = URIRef(NAMESPACE + 'RequestAdvise-RECIPIENT')
RequestAdvise_SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'RequestAdvise-SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC')
RequestAdvise_THREATEN_VIOLENCE_AGENT_RECIPIENT = URIRef(NAMESPACE + 'RequestAdvise-THREATEN_VIOLENCE_AGENT_RECIPIENT')
RequestAdvise_TOPIC = URIRef(NAMESPACE + 'RequestAdvise-TOPIC')
Rescue = URIRef(NAMESPACE + 'Rescue')
RescueEvent = URIRef(NAMESPACE + 'RescueEvent')
RescueEvent_AGENT = URIRef(NAMESPACE + 'RescueEvent-AGENT')
RescueEvent_DANGEROUS_INITIAL_LOCATION = URIRef(NAMESPACE + 'RescueEvent-DANGEROUS_INITIAL_LOCATION')
RescueEvent_DESTINATION = URIRef(NAMESPACE + 'RescueEvent-DESTINATION')
RescueEvent_PATIENT = URIRef(NAMESPACE + 'RescueEvent-PATIENT')
RescueEvent_RESOLVE_DANGER_TO_AGENT_PATIENT = URIRef(NAMESPACE + 'RescueEvent-RESOLVE_DANGER_TO_AGENT_PATIENT')
RescueEvent_START_AT_LOCATION_PATIENT_INITIAL_LOCATION = URIRef(NAMESPACE + 'RescueEvent-START_AT_LOCATION_PATIENT_INITIAL_LOCATION')
RescueEvent_TOPIC = URIRef(NAMESPACE + 'RescueEvent-TOPIC')
RescueEvent_VOLITIONAL_AGENT = URIRef(NAMESPACE + 'RescueEvent-VOLITIONAL_AGENT')
Rescue_AGENT = URIRef(NAMESPACE + 'Rescue-AGENT')
Rescue_PATIENT = URIRef(NAMESPACE + 'Rescue-PATIENT')
Rescue_TOPIC = URIRef(NAMESPACE + 'Rescue-TOPIC')
RideOperateVehicle = URIRef(NAMESPACE + 'RideOperateVehicle')
RideOperateVehicle_CHANGES_LOCATION_INSTR = URIRef(NAMESPACE + 'RideOperateVehicle-CHANGES_LOCATION_INSTR')
RideOperateVehicle_COLOCATED_THEME_INSTR = URIRef(NAMESPACE + 'RideOperateVehicle-COLOCATED_THEME_INSTR')
RideOperateVehicle_INSTR = URIRef(NAMESPACE + 'RideOperateVehicle-INSTR')
RideOperateVehicle_THEME = URIRef(NAMESPACE + 'RideOperateVehicle-THEME')
Role = URIRef(NAMESPACE + 'Role')
SELF_MOTION_COTHEME = URIRef(NAMESPACE + 'SELF_MOTION_COTHEME')
SELF_MOTION_THEME = URIRef(NAMESPACE + 'SELF_MOTION_THEME')
SELF_MOTION_THEME_ = URIRef(NAMESPACE + 'SELF_MOTION_THEME-')
SENTENCE = URIRef(NAMESPACE + 'SENTENCE')
SENTIENT_INSTR_ = URIRef(NAMESPACE + 'SENTIENT_INSTR-')
SENTIENT_PATIENT = URIRef(NAMESPACE + 'SENTIENT_PATIENT')
SENTIENT_PATIENT_ = URIRef(NAMESPACE + 'SENTIENT_PATIENT-')
SOURCE = URIRef(NAMESPACE + 'SOURCE')
START_AT_LOCATION_ADJUDICATOR_DESTINATION = URIRef(NAMESPACE + 'START_AT_LOCATION_ADJUDICATOR_DESTINATION')
START_AT_LOCATION_AGENT_INITIAL_LOCATION = URIRef(NAMESPACE + 'START_AT_LOCATION_AGENT_INITIAL_LOCATION')
START_AT_LOCATION_COTHEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'START_AT_LOCATION_COTHEME_INITIAL_LOCATION')
START_AT_LOCATION_DEFENDANT_DESTINATION_ = URIRef(NAMESPACE + 'START_AT_LOCATION_DEFENDANT_DESTINATION-')
START_AT_LOCATION_DEFENDANT_INITIAL_LOCATION = URIRef(NAMESPACE + 'START_AT_LOCATION_DEFENDANT_INITIAL_LOCATION')
START_AT_LOCATION_PATIENT_INITIAL_LOCATION = URIRef(NAMESPACE + 'START_AT_LOCATION_PATIENT_INITIAL_LOCATION')
START_AT_LOCATION_RECIPIENT_DESTINATION = URIRef(NAMESPACE + 'START_AT_LOCATION_RECIPIENT_DESTINATION')
START_AT_LOCATION_THEME_DESTINATION_ = URIRef(NAMESPACE + 'START_AT_LOCATION_THEME_DESTINATION-')
START_AT_LOCATION_THEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'START_AT_LOCATION_THEME_INITIAL_LOCATION')
SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC')
SelfDirectedBattle = URIRef(NAMESPACE + 'SelfDirectedBattle')
SelfDirectedBattle_AGENT = URIRef(NAMESPACE + 'SelfDirectedBattle-AGENT')
SelfDirectedBattle_ATTEMPT_HARM_AGENT_AGENT = URIRef(NAMESPACE + 'SelfDirectedBattle-ATTEMPT_HARM_AGENT_AGENT')
SelfDirectedBattle_DISTRIBUTED_RECIPROCAL_AGENT = URIRef(NAMESPACE + 'SelfDirectedBattle-DISTRIBUTED_RECIPROCAL_AGENT')
SelfDirectedBattle_ENTROPY_INCREASE_PATIENT = URIRef(NAMESPACE + 'SelfDirectedBattle-ENTROPY_INCREASE_PATIENT')
SelfDirectedBattle_PATIENT = URIRef(NAMESPACE + 'SelfDirectedBattle-PATIENT')
SelfDirectedBattle_PHYSICALACTION = URIRef(NAMESPACE + 'SelfDirectedBattle-PHYSICALACTION')
SelfDirectedBattle_POLITICAL_ = URIRef(NAMESPACE + 'SelfDirectedBattle-POLITICAL-')
SelfDirectedBattle_VIOLENT = URIRef(NAMESPACE + 'SelfDirectedBattle-VIOLENT')
SelfMotion = URIRef(NAMESPACE + 'SelfMotion')
SelfMotion_DESTINATION = URIRef(NAMESPACE + 'SelfMotion-DESTINATION')
SelfMotion_MOTION_IS_HORIZONAL = URIRef(NAMESPACE + 'SelfMotion-MOTION_IS_HORIZONAL')
SelfMotion_SELF_MOTION_THEME = URIRef(NAMESPACE + 'SelfMotion-SELF_MOTION_THEME')
SelfMotion_THEME = URIRef(NAMESPACE + 'SelfMotion-THEME')
SelfMotion_VOLITIONAL_THEME = URIRef(NAMESPACE + 'SelfMotion-VOLITIONAL_THEME')
SendSupplyExport = URIRef(NAMESPACE + 'SendSupplyExport')
SendSupplyExport_AGENT = URIRef(NAMESPACE + 'SendSupplyExport-AGENT')
SendSupplyExport_CHANGES_LOCATION_AGENT_ = URIRef(NAMESPACE + 'SendSupplyExport-CHANGES_LOCATION_AGENT-')
SendSupplyExport_DESTINATION = URIRef(NAMESPACE + 'SendSupplyExport-DESTINATION')
SendSupplyExport_INITIAL_LOCATION = URIRef(NAMESPACE + 'SendSupplyExport-INITIAL_LOCATION')
SendSupplyExport_LOSE_POSSESSION_AGENT_THEME = URIRef(NAMESPACE + 'SendSupplyExport-LOSE_POSSESSION_AGENT_THEME')
SendSupplyExport_MOTION_IS_HORIZONAL = URIRef(NAMESPACE + 'SendSupplyExport-MOTION_IS_HORIZONAL')
SendSupplyExport_SELF_MOTION_THEME_ = URIRef(NAMESPACE + 'SendSupplyExport-SELF_MOTION_THEME-')
SendSupplyExport_START_AT_LOCATION_AGENT_INITIAL_LOCATION = URIRef(NAMESPACE + 'SendSupplyExport-START_AT_LOCATION_AGENT_INITIAL_LOCATION')
SendSupplyExport_START_AT_LOCATION_THEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'SendSupplyExport-START_AT_LOCATION_THEME_INITIAL_LOCATION')
SendSupplyExport_THEME = URIRef(NAMESPACE + 'SendSupplyExport-THEME')
SendSupplyExport_VOLITIONAL_AGENT = URIRef(NAMESPACE + 'SendSupplyExport-VOLITIONAL_AGENT')
SensoryObserve = URIRef(NAMESPACE + 'SensoryObserve')
SensoryObserve_AGENT = URIRef(NAMESPACE + 'SensoryObserve-AGENT')
SensoryObserve_DIRECTLY_OBSERVE_AGENT_PATIENT = URIRef(NAMESPACE + 'SensoryObserve-DIRECTLY_OBSERVE_AGENT_PATIENT')
SensoryObserve_GET_INFO_AGENT_PATIENT = URIRef(NAMESPACE + 'SensoryObserve-GET_INFO_AGENT_PATIENT')
SensoryObserve_INSTR = URIRef(NAMESPACE + 'SensoryObserve-INSTR')
SensoryObserve_PATIENT = URIRef(NAMESPACE + 'SensoryObserve-PATIENT')
SmuggleExtract = URIRef(NAMESPACE + 'SmuggleExtract')
SmuggleExtract_CHANGES_LOCATION_COTHEME = URIRef(NAMESPACE + 'SmuggleExtract-CHANGES_LOCATION_COTHEME')
SmuggleExtract_COLOCATED_THEME_COTHEME = URIRef(NAMESPACE + 'SmuggleExtract-COLOCATED_THEME_COTHEME')
SmuggleExtract_COTHEME = URIRef(NAMESPACE + 'SmuggleExtract-COTHEME')
SmuggleExtract_DESTINATION = URIRef(NAMESPACE + 'SmuggleExtract-DESTINATION')
SmuggleExtract_INITIAL_LOCATION = URIRef(NAMESPACE + 'SmuggleExtract-INITIAL_LOCATION')
SmuggleExtract_IS_CRIME_OR_CRIMINAL = URIRef(NAMESPACE + 'SmuggleExtract-IS_CRIME_OR_CRIMINAL')
SmuggleExtract_SELF_MOTION_THEME = URIRef(NAMESPACE + 'SmuggleExtract-SELF_MOTION_THEME')
SmuggleExtract_THEME = URIRef(NAMESPACE + 'SmuggleExtract-THEME')
SmuggleExtract_VOLITIONAL_THEME = URIRef(NAMESPACE + 'SmuggleExtract-VOLITIONAL_THEME')
SocialEvent = URIRef(NAMESPACE + 'SocialEvent')
Spy = URIRef(NAMESPACE + 'Spy')
Spy_AGENT = URIRef(NAMESPACE + 'Spy-AGENT')
Spy_AWARE_OF_EVENT_PATIENT_ = URIRef(NAMESPACE + 'Spy-AWARE_OF_EVENT_PATIENT-')
Spy_BENEFICIARY = URIRef(NAMESPACE + 'Spy-BENEFICIARY')
Spy_GET_INFO_BENEFICIARY_PATIENT = URIRef(NAMESPACE + 'Spy-GET_INFO_BENEFICIARY_PATIENT')
Spy_PATIENT = URIRef(NAMESPACE + 'Spy-PATIENT')
StartEnd_Directed_SocialRelations = URIRef(NAMESPACE + 'StartEnd_Directed_SocialRelations')
StartEnd_Directed_SocialRelations_EMPLOYEE = URIRef(NAMESPACE + 'StartEnd_Directed_SocialRelations-EMPLOYEE')
StartEnd_Directed_SocialRelations_EMPLOYER = URIRef(NAMESPACE + 'StartEnd_Directed_SocialRelations-EMPLOYER')
StartEnd_Directed_SocialRelations_INITIAL_LOCATION = URIRef(NAMESPACE + 'StartEnd_Directed_SocialRelations-INITIAL_LOCATION')
StartEnd_Directed_SocialRelations_POSITION = URIRef(NAMESPACE + 'StartEnd_Directed_SocialRelations-POSITION')
StartOrg = URIRef(NAMESPACE + 'StartOrg')
StartOrg_AGENT = URIRef(NAMESPACE + 'StartOrg-AGENT')
StartOrg_BUSINESS = URIRef(NAMESPACE + 'StartOrg-BUSINESS')
StartOrg_CREATED_PATIENT = URIRef(NAMESPACE + 'StartOrg-CREATED_PATIENT')
StartOrg_DESTROYED_PATIENT_ = URIRef(NAMESPACE + 'StartOrg-DESTROYED_PATIENT-')
StartOrg_FAMILY_MARITAL_ = URIRef(NAMESPACE + 'StartOrg-FAMILY_MARITAL-')
StartOrg_PATIENT = URIRef(NAMESPACE + 'StartOrg-PATIENT')
StartOrg_VOLITIONAL_AGENT = URIRef(NAMESPACE + 'StartOrg-VOLITIONAL_AGENT')
StealRobHijack = URIRef(NAMESPACE + 'StealRobHijack')
StealRobHijack_DONOR = URIRef(NAMESPACE + 'StealRobHijack-DONOR')
StealRobHijack_LOSE_POSSESSION_DONOR_PATIENT_ = URIRef(NAMESPACE + 'StealRobHijack-LOSE_POSSESSION_DONOR_PATIENT-')
StealRobHijack_PATIENT = URIRef(NAMESPACE + 'StealRobHijack-PATIENT')
StealRobHijack_RECIPIENT = URIRef(NAMESPACE + 'StealRobHijack-RECIPIENT')
StealRobHijack_VOLITIONAL_DONOR_ = URIRef(NAMESPACE + 'StealRobHijack-VOLITIONAL_DONOR-')
StudySubject = URIRef(NAMESPACE + 'StudySubject')
StudySubject_AGENT = URIRef(NAMESPACE + 'StudySubject-AGENT')
StudySubject_GET_INFO_AGENT_PATIENT = URIRef(NAMESPACE + 'StudySubject-GET_INFO_AGENT_PATIENT')
StudySubject_PATIENT = URIRef(NAMESPACE + 'StudySubject-PATIENT')
Sue = URIRef(NAMESPACE + 'Sue')
Sue_ADJUDICATOR = URIRef(NAMESPACE + 'Sue-ADJUDICATOR')
Sue_AFTER_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Sue-AFTER_TRIAL_HEARING-')
Sue_BEFORE_TRIAL_HEARING = URIRef(NAMESPACE + 'Sue-BEFORE_TRIAL_HEARING')
Sue_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Sue-CRIME_OR_CAUSE')
Sue_DEFENDANT = URIRef(NAMESPACE + 'Sue-DEFENDANT')
Sue_DURING_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Sue-DURING_TRIAL_HEARING-')
Sue_PROSECUTOR = URIRef(NAMESPACE + 'Sue-PROSECUTOR')
Sue_SENTENCE = URIRef(NAMESPACE + 'Sue-SENTENCE')
Suicide = URIRef(NAMESPACE + 'Suicide')
Suicide_AGENT = URIRef(NAMESPACE + 'Suicide-AGENT')
Suicide_ATTEMPT_HARM_AGENT_AGENT = URIRef(NAMESPACE + 'Suicide-ATTEMPT_HARM_AGENT_AGENT')
Suicide_DESTROYED_AGENT = URIRef(NAMESPACE + 'Suicide-DESTROYED_AGENT')
Suicide_ENTROPY_INCREASE_AGENT = URIRef(NAMESPACE + 'Suicide-ENTROPY_INCREASE_AGENT')
Suicide_PHYSICALACTION = URIRef(NAMESPACE + 'Suicide-PHYSICALACTION')
Suicide_POLITICAL_ = URIRef(NAMESPACE + 'Suicide-POLITICAL-')
Suicide_VIOLENT = URIRef(NAMESPACE + 'Suicide-VIOLENT')
TARGET_IS_COMPUTER_SYSTEM = URIRef(NAMESPACE + 'TARGET_IS_COMPUTER_SYSTEM')
THEME = URIRef(NAMESPACE + 'THEME')
THREATEN_VIOLENCE_AGENT_RECIPIENT = URIRef(NAMESPACE + 'THREATEN_VIOLENCE_AGENT_RECIPIENT')
THREATEN_VIOLENCE_AGENT_RECIPIENT_ = URIRef(NAMESPACE + 'THREATEN_VIOLENCE_AGENT_RECIPIENT-')
TOPIC = URIRef(NAMESPACE + 'TOPIC')
TRAVERSE_THEME_DESTINATION = URIRef(NAMESPACE + 'TRAVERSE_THEME_DESTINATION')
Terrorism = URIRef(NAMESPACE + 'Terrorism')
Terrorism_AGENT = URIRef(NAMESPACE + 'Terrorism-AGENT')
Terrorism_ATTEMPT_HARM_AGENT_PATIENT = URIRef(NAMESPACE + 'Terrorism-ATTEMPT_HARM_AGENT_PATIENT')
Terrorism_DESTROYED_PATIENT = URIRef(NAMESPACE + 'Terrorism-DESTROYED_PATIENT')
Terrorism_ENTROPY_INCREASE_AGENT = URIRef(NAMESPACE + 'Terrorism-ENTROPY_INCREASE_AGENT')
Terrorism_INSTR = URIRef(NAMESPACE + 'Terrorism-INSTR')
Terrorism_LARGE_NUMBERS_PATIENT = URIRef(NAMESPACE + 'Terrorism-LARGE_NUMBERS_PATIENT')
Terrorism_PATIENT = URIRef(NAMESPACE + 'Terrorism-PATIENT')
Terrorism_PHYSICALACTION_ = URIRef(NAMESPACE + 'Terrorism-PHYSICALACTION-')
Terrorism_TOPIC = URIRef(NAMESPACE + 'Terrorism-TOPIC')
Terrorism_VIOLENT = URIRef(NAMESPACE + 'Terrorism-VIOLENT')
ThreatenCoerce = URIRef(NAMESPACE + 'ThreatenCoerce')
ThreatenCoerce_AGENT = URIRef(NAMESPACE + 'ThreatenCoerce-AGENT')
ThreatenCoerce_COMM_ONEWAY = URIRef(NAMESPACE + 'ThreatenCoerce-COMM-ONEWAY')
ThreatenCoerce_DISCUSS_POSSIBLE_ACTION_BY_AGENT = URIRef(NAMESPACE + 'ThreatenCoerce-DISCUSS_POSSIBLE_ACTION_BY_AGENT')
ThreatenCoerce_DISCUSS_POSSIBLE_ACTION_BY_RECIPIENT = URIRef(NAMESPACE + 'ThreatenCoerce-DISCUSS_POSSIBLE_ACTION_BY_RECIPIENT')
ThreatenCoerce_RECIPIENT = URIRef(NAMESPACE + 'ThreatenCoerce-RECIPIENT')
ThreatenCoerce_SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC = URIRef(NAMESPACE + 'ThreatenCoerce-SUGGEST_THAT_X_CONSIDER_Y_RECIPIENT_TOPIC')
ThreatenCoerce_THREATEN_VIOLENCE_AGENT_RECIPIENT = URIRef(NAMESPACE + 'ThreatenCoerce-THREATEN_VIOLENCE_AGENT_RECIPIENT')
ThreatenCoerce_TOPIC = URIRef(NAMESPACE + 'ThreatenCoerce-TOPIC')
Traffic_person = URIRef(NAMESPACE + 'Traffic_person')
Traffic_person_CHANGES_LOCATION_COTHEME = URIRef(NAMESPACE + 'Traffic_person-CHANGES_LOCATION_COTHEME')
Traffic_person_COLOCATED_THEME_COTHEME = URIRef(NAMESPACE + 'Traffic_person-COLOCATED_THEME_COTHEME')
Traffic_person_COTHEME = URIRef(NAMESPACE + 'Traffic_person-COTHEME')
Traffic_person_DESTINATION = URIRef(NAMESPACE + 'Traffic_person-DESTINATION')
Traffic_person_IS_CRIME_OR_CRIMINAL = URIRef(NAMESPACE + 'Traffic_person-IS_CRIME_OR_CRIMINAL')
Traffic_person_SELF_MOTION_THEME = URIRef(NAMESPACE + 'Traffic_person-SELF_MOTION_THEME')
Traffic_person_THEME = URIRef(NAMESPACE + 'Traffic_person-THEME')
Traffic_person_VOLITIONAL_THEME = URIRef(NAMESPACE + 'Traffic_person-VOLITIONAL_THEME')
TransactionEvent = URIRef(NAMESPACE + 'TransactionEvent')
TransactionEvent_ASSET = URIRef(NAMESPACE + 'TransactionEvent-ASSET')
TransactionEvent_DONOR = URIRef(NAMESPACE + 'TransactionEvent-DONOR')
TransactionEvent_PATIENT = URIRef(NAMESPACE + 'TransactionEvent-PATIENT')
TransactionEvent_RECIPIENT = URIRef(NAMESPACE + 'TransactionEvent-RECIPIENT')
TransferControl = URIRef(NAMESPACE + 'TransferControl')
TransferControl_DONOR = URIRef(NAMESPACE + 'TransferControl-DONOR')
TransferControl_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'TransferControl-GAIN_POSSESSION_RECIPIENT_PATIENT')
TransferControl_LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'TransferControl-LEGALLY_IMPOSED-')
TransferControl_LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'TransferControl-LOSE_POSSESSION_DONOR_PATIENT')
TransferControl_PATIENT = URIRef(NAMESPACE + 'TransferControl-PATIENT')
TransferControl_RECIPIENT = URIRef(NAMESPACE + 'TransferControl-RECIPIENT')
Traverse = URIRef(NAMESPACE + 'Traverse')
Traverse_COLOCATED_THEME_DESTINATION = URIRef(NAMESPACE + 'Traverse-COLOCATED_THEME_DESTINATION')
Traverse_DESTINATION = URIRef(NAMESPACE + 'Traverse-DESTINATION')
Traverse_END_AT_LOCATION_THEME_DESTINATION_ = URIRef(NAMESPACE + 'Traverse-END_AT_LOCATION_THEME_DESTINATION-')
Traverse_SELF_MOTION_THEME = URIRef(NAMESPACE + 'Traverse-SELF_MOTION_THEME')
Traverse_START_AT_LOCATION_THEME_DESTINATION_ = URIRef(NAMESPACE + 'Traverse-START_AT_LOCATION_THEME_DESTINATION-')
Traverse_THEME = URIRef(NAMESPACE + 'Traverse-THEME')
Traverse_TRAVERSE_THEME_DESTINATION = URIRef(NAMESPACE + 'Traverse-TRAVERSE_THEME_DESTINATION')
Trialhearing = URIRef(NAMESPACE + 'Trialhearing')
Trialhearing_ADJUDICATOR = URIRef(NAMESPACE + 'Trialhearing-ADJUDICATOR')
Trialhearing_AFTER_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Trialhearing-AFTER_TRIAL_HEARING-')
Trialhearing_BEFORE_TRIAL_HEARING_ = URIRef(NAMESPACE + 'Trialhearing-BEFORE_TRIAL_HEARING-')
Trialhearing_CRIME_OR_CAUSE = URIRef(NAMESPACE + 'Trialhearing-CRIME_OR_CAUSE')
Trialhearing_DEFENDANT = URIRef(NAMESPACE + 'Trialhearing-DEFENDANT')
Trialhearing_DURING_TRIAL_HEARING = URIRef(NAMESPACE + 'Trialhearing-DURING_TRIAL_HEARING')
Trialhearing_PROSECUTOR = URIRef(NAMESPACE + 'Trialhearing-PROSECUTOR')
Two_Way_ExchangeBarter = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter')
Two_Way_ExchangeBarter_ASSET = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter-ASSET')
Two_Way_ExchangeBarter_DONOR = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter-DONOR')
Two_Way_ExchangeBarter_GAIN_POSSESSION_DONOR_ASSET = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter-GAIN_POSSESSION_DONOR_ASSET')
Two_Way_ExchangeBarter_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter-GAIN_POSSESSION_RECIPIENT_PATIENT')
Two_Way_ExchangeBarter_LEGALLY_IMPOSED_ = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter-LEGALLY_IMPOSED-')
Two_Way_ExchangeBarter_LOSE_POSSESSION_DONOR_PATIENT = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter-LOSE_POSSESSION_DONOR_PATIENT')
Two_Way_ExchangeBarter_LOSE_POSSESSION_RECIPIENT_ASSET = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter-LOSE_POSSESSION_RECIPIENT_ASSET')
Two_Way_ExchangeBarter_PATIENT = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter-PATIENT')
Two_Way_ExchangeBarter_RECIPIENT = URIRef(NAMESPACE + 'Two_Way_ExchangeBarter-RECIPIENT')
USE_AGENT_INSTR = URIRef(NAMESPACE + 'USE_AGENT_INSTR')
Undirected_ConventionFestival = URIRef(NAMESPACE + 'Undirected_ConventionFestival')
Undirected_ConventionFestival_AGENT = URIRef(NAMESPACE + 'Undirected_ConventionFestival-AGENT')
Undirected_ConventionFestival_COLOCATED_TOPIC_GROUP = URIRef(NAMESPACE + 'Undirected_ConventionFestival-COLOCATED_TOPIC_GROUP')
Undirected_ConventionFestival_CROWD_ACTIVITY_GROUP = URIRef(NAMESPACE + 'Undirected_ConventionFestival-CROWD_ACTIVITY_GROUP')
Undirected_ConventionFestival_CULTURAL_RELIGIOUS_ = URIRef(NAMESPACE + 'Undirected_ConventionFestival-CULTURAL_RELIGIOUS-')
Undirected_ConventionFestival_GET_INFO_GROUP_TOPIC = URIRef(NAMESPACE + 'Undirected_ConventionFestival-GET_INFO_GROUP_TOPIC')
Undirected_ConventionFestival_GROUP = URIRef(NAMESPACE + 'Undirected_ConventionFestival-GROUP')
Undirected_ConventionFestival_INSTIGATES_AGENT = URIRef(NAMESPACE + 'Undirected_ConventionFestival-INSTIGATES_AGENT')
Undirected_ConventionFestival_LARGE_NUMBERS_GROUP = URIRef(NAMESPACE + 'Undirected_ConventionFestival-LARGE_NUMBERS_GROUP')
Undirected_ConventionFestival_POLITICAL_ = URIRef(NAMESPACE + 'Undirected_ConventionFestival-POLITICAL-')
Undirected_ConventionFestival_TOPIC = URIRef(NAMESPACE + 'Undirected_ConventionFestival-TOPIC')
VIOLENT = URIRef(NAMESPACE + 'VIOLENT')
VIOLENT_ = URIRef(NAMESPACE + 'VIOLENT-')
VOLITIONAL_ = URIRef(NAMESPACE + 'VOLITIONAL-')
VOLITIONAL_AGENT = URIRef(NAMESPACE + 'VOLITIONAL_AGENT')
VOLITIONAL_DEFENDANT_ = URIRef(NAMESPACE + 'VOLITIONAL_DEFENDANT-')
VOLITIONAL_DESTINATION_ = URIRef(NAMESPACE + 'VOLITIONAL_DESTINATION-')
VOLITIONAL_DONOR_ = URIRef(NAMESPACE + 'VOLITIONAL_DONOR-')
VOLITIONAL_EMPLOYEE = URIRef(NAMESPACE + 'VOLITIONAL_EMPLOYEE')
VOLITIONAL_EMPLOYEE_ = URIRef(NAMESPACE + 'VOLITIONAL_EMPLOYEE-')
VOLITIONAL_EMPLOYER = URIRef(NAMESPACE + 'VOLITIONAL_EMPLOYER')
VOLITIONAL_PATIENT = URIRef(NAMESPACE + 'VOLITIONAL_PATIENT')
VOLITIONAL_RECIPIENT = URIRef(NAMESPACE + 'VOLITIONAL_RECIPIENT')
VOLITIONAL_THEME = URIRef(NAMESPACE + 'VOLITIONAL_THEME')
VOLITIONAL_THEME_ = URIRef(NAMESPACE + 'VOLITIONAL_THEME-')
VOTER = URIRef(NAMESPACE + 'VOTER')
VerbalFight = URIRef(NAMESPACE + 'VerbalFight')
VerbalFight_AGENT = URIRef(NAMESPACE + 'VerbalFight-AGENT')
VerbalFight_COMMUNICATE_TO_AGENT_PATIENT = URIRef(NAMESPACE + 'VerbalFight-COMMUNICATE_TO_AGENT_PATIENT')
VerbalFight_ENTROPY_INCREASE_AGENT = URIRef(NAMESPACE + 'VerbalFight-ENTROPY_INCREASE_AGENT')
VerbalFight_INSTR = URIRef(NAMESPACE + 'VerbalFight-INSTR')
VerbalFight_MEDIUM_IS_INTERNET_ = URIRef(NAMESPACE + 'VerbalFight-MEDIUM_IS_INTERNET-')
VerbalFight_PATIENT = URIRef(NAMESPACE + 'VerbalFight-PATIENT')
VerticalMotion_ClimbLift = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift')
VerticalMotion_ClimbLift_AGENT = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-AGENT')
VerticalMotion_ClimbLift_CHANGES_LOCATION_AGENT_ = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-CHANGES_LOCATION_AGENT-')
VerticalMotion_ClimbLift_DESTINATION = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-DESTINATION')
VerticalMotion_ClimbLift_INITIAL_LOCATION = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-INITIAL_LOCATION')
VerticalMotion_ClimbLift_LOSE_POSSESSION_AGENT_THEME = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-LOSE_POSSESSION_AGENT_THEME')
VerticalMotion_ClimbLift_MOTION_IS_HORIZONAL_ = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-MOTION_IS_HORIZONAL-')
VerticalMotion_ClimbLift_PROJECTILE_MANNER_ = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-PROJECTILE_MANNER-')
VerticalMotion_ClimbLift_SELF_MOTION_THEME_ = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-SELF_MOTION_THEME-')
VerticalMotion_ClimbLift_START_AT_LOCATION_AGENT_INITIAL_LOCATION = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-START_AT_LOCATION_AGENT_INITIAL_LOCATION')
VerticalMotion_ClimbLift_START_AT_LOCATION_THEME_INITIAL_LOCATION = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-START_AT_LOCATION_THEME_INITIAL_LOCATION')
VerticalMotion_ClimbLift_THEME = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-THEME')
VerticalMotion_ClimbLift_VIOLENT_ = URIRef(NAMESPACE + 'VerticalMotion_ClimbLift-VIOLENT-')
ViolentChangeOfPossession = URIRef(NAMESPACE + 'ViolentChangeOfPossession')
ViolentChangeOfPossession_DONOR = URIRef(NAMESPACE + 'ViolentChangeOfPossession-DONOR')
ViolentChangeOfPossession_GAIN_POSSESSION_RECIPIENT_PATIENT = URIRef(NAMESPACE + 'ViolentChangeOfPossession-GAIN_POSSESSION_RECIPIENT_PATIENT')
ViolentChangeOfPossession_PATIENT = URIRef(NAMESPACE + 'ViolentChangeOfPossession-PATIENT')
ViolentChangeOfPossession_POLITICAL_ = URIRef(NAMESPACE + 'ViolentChangeOfPossession-POLITICAL-')
ViolentChangeOfPossession_RECIPIENT = URIRef(NAMESPACE + 'ViolentChangeOfPossession-RECIPIENT')
ViolentChangeOfPossession_VIOLENT = URIRef(NAMESPACE + 'ViolentChangeOfPossession-VIOLENT')
ViolentChangeOfPossession_VOLITIONAL_RECIPIENT = URIRef(NAMESPACE + 'ViolentChangeOfPossession-VOLITIONAL_RECIPIENT')
VisitAttendEvent = URIRef(NAMESPACE + 'VisitAttendEvent')
VisitAttendEvent_COLOCATED_THEME_DESTINATION = URIRef(NAMESPACE + 'VisitAttendEvent-COLOCATED_THEME_DESTINATION')
VisitAttendEvent_DESTINATION = URIRef(NAMESPACE + 'VisitAttendEvent-DESTINATION')
VisitAttendEvent_END_AT_LOCATION_THEME_DESTINATION_ = URIRef(NAMESPACE + 'VisitAttendEvent-END_AT_LOCATION_THEME_DESTINATION-')
VisitAttendEvent_SELF_MOTION_THEME = URIRef(NAMESPACE + 'VisitAttendEvent-SELF_MOTION_THEME')
VisitAttendEvent_START_AT_LOCATION_THEME_DESTINATION_ = URIRef(NAMESPACE + 'VisitAttendEvent-START_AT_LOCATION_THEME_DESTINATION-')
VisitAttendEvent_THEME = URIRef(NAMESPACE + 'VisitAttendEvent-THEME')
Win_Election = URIRef(NAMESPACE + 'Win_Election')
Win_Election_CANDIDATE = URIRef(NAMESPACE + 'Win_Election-CANDIDATE')
Win_Election_EXPRESS_FAVOR_FOR_VOTER_CANDIDATE = URIRef(NAMESPACE + 'Win_Election-EXPRESS_FAVOR_FOR_VOTER_CANDIDATE')
Win_Election_GAIN_POSITION_CANDIDATE_POSITION = URIRef(NAMESPACE + 'Win_Election-GAIN_POSITION_CANDIDATE_POSITION')
Win_Election_GAIN_POWER_OVER_CANDIDATE_VOTER = URIRef(NAMESPACE + 'Win_Election-GAIN_POWER_OVER_CANDIDATE_VOTER')
Win_Election_POSITION = URIRef(NAMESPACE + 'Win_Election-POSITION')
Win_Election_PUBLIC_VOTE = URIRef(NAMESPACE + 'Win_Election-PUBLIC_VOTE')
Win_Election_REPRESENT_ORG_GPE_CANDIDATE = URIRef(NAMESPACE + 'Win_Election-REPRESENT_ORG_GPE_CANDIDATE')
Win_Election_RESULT = URIRef(NAMESPACE + 'Win_Election-RESULT')
Win_Election_VOTER = URIRef(NAMESPACE + 'Win_Election-VOTER')
hasFeature = URIRef(NAMESPACE + 'hasFeature')
hasPrototypicalValue = URIRef(NAMESPACE + 'hasPrototypicalValue')
hasRole = URIRef(NAMESPACE + 'hasRole')
hasSubtypeFeature = URIRef(NAMESPACE + 'hasSubtypeFeature')
hasSubtypeRole = URIRef(NAMESPACE + 'hasSubtypeRole')
hasType = URIRef(NAMESPACE + 'hasType')
